@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -15,6 +15,7 @@ proc AnalysisDef {} {
     set ianalysis(menu,hmenu,count) 0
     set ianalysis(menu,hmenu) {}
     set ianalysis(bind,count) 0
+    set ianalysis(buttonbar,count) 0
     set ianalysis(param,count) 0
     set ianalysis(param,seq) 0
     set ianalysis(file) ".$ds9(app).ans"
@@ -117,6 +118,23 @@ proc ClearAnalysis {} {
 	unset ianalysis(param,$ii,count)
     }
     set ianalysis(param,count) 0
+
+    # clear buttonbar
+    DestroyButtonbarAnalysis
+
+    for {set ii 0} {$ii<$ianalysis(buttonbar,count)} {incr ii} {
+	for {set jj 0} {$jj<$ianalysis(buttonbar,$ii,count)} {incr jj} {
+	    unset ianalysis(buttonbar,$ii-$jj,button)
+	    unset ianalysis(buttonbar,$ii-$jj,item)
+	    unset ianalysis(buttonbar,$ii-$jj,template)
+	    unset ianalysis(buttonbar,$ii-$jj,cmd)
+	    unset ianalysis(buttonbar,$ii-$jj,inuse)
+	}
+	unset ianalysis(buttonbar,$ii,count)
+    }
+    set ianalysis(buttonbar,count) 0
+
+    LayoutView
 }
 
 proc InitAnalysisFile {} {
@@ -301,6 +319,20 @@ proc ProcessAnalysis {varname} {
 		    continue
 		}
 
+		# buttonbar
+		if {[lindex $line 0] == {buttonbar}} {
+		    set ii $ianalysis(buttonbar,count)
+		    set ianalysis(buttonbar,$ii,count) 0
+		    continue
+		}
+
+		# end buttonbar
+		if {[lindex $line 0] == {endbuttonbar}} {
+		    CreateButtonbarAnalysis
+		    continue
+		}
+
+		# separator
 		if {[lindex $line 0] == {---}} {
 		    $currentparent add separator
 		    continue
@@ -327,8 +359,7 @@ proc ProcessAnalysis {varname} {
 
 	    4 {
 		set cmd "$line"
-		if {$item != {} && $template != {} && 
-		    $type != {} && $cmd != {}} {
+		if {$item != {} && $template != {} && $type != {} && $cmd != {}} {
 		    switch -- [lindex $type 0] {
 			bind {
 			    set bb [lindex $type 1]
@@ -367,6 +398,17 @@ proc ProcessAnalysis {varname} {
 				-selectcolor green
 			    incr ianalysis(menu,count)
 			}
+			button {
+			    set ii $ianalysis(buttonbar,count)
+			    set jj $ianalysis(buttonbar,$ii,count)
+
+			    set ianalysis(buttonbar,$ii-$jj,button) {}
+			    set ianalysis(buttonbar,$ii-$jj,item) "$item"
+			    set ianalysis(buttonbar,$ii-$jj,template) "$template"
+			    set ianalysis(buttonbar,$ii-$jj,cmd) "$cmd"
+			    set ianalysis(buttonbar,$ii-$jj,inuse) 0
+			    incr ianalysis(buttonbar,$ii,count)
+			}
 			default {
 			    # something really wrong here, abort
 			    return 0
@@ -442,8 +484,7 @@ proc ProcessAnalysis {varname} {
 
 	    6 {
 		# end help
-		if {[lindex $line 0] == {endhelp} ||
-		    [lindex $line 0] == {end}} {
+		if {[lindex $line 0] == {endhelp} || [lindex $line 0] == {end}} {
 		    incr ianalysis(menu,count)
 		    set state 1
 		    continue
@@ -455,11 +496,12 @@ proc ProcessAnalysis {varname} {
 	}
     }
 
-    # events
+    # enable events
     UnBindEventsCanvas
     BindEventsCanvas
 
     UpdateAnalysisMenu
+    UpdateAnalysisButtonbar
 
     return 1
 }
@@ -963,7 +1005,10 @@ proc AnalysisPlotStdin {type w wtt result} {
 	switch $type {
 	    line {PlotLine $w $wtt $t $x $y $d $rr false}
 	    bar {PlotBar $w $wtt $t $x $y $d $rr false}
-	    scatter {PlotScatter $w $wtt $t $x $y $d $rr false}
+	    scatter {
+		# backward compatibility
+		PlotScatter $w $wtt $t $x $y $d $rr false
+	    }
 	}
     } else {
 	Error "[msgcat::mc {Error}] [string range $tt 0 40]"
@@ -2023,7 +2068,7 @@ proc AnalysisSendCmd {} {
     global ianalysis
 
     for {set ii 0} {$ii<$ianalysis(menu,count)} {incr ii} {
-	append result "\#$ii menu"
+	append result "menu [expr $ii+1]"
 	append result "\n$ianalysis(menu,$ii,item)"
 	append result "\n$ianalysis(menu,$ii,template)"
 	if {$ianalysis(menu,$ii,cmd) != {web}} {
@@ -2035,9 +2080,10 @@ proc AnalysisSendCmd {} {
 	}
 	append result "\n\n"
     }
+
     for {set ii 0} {$ii<$ianalysis(bind,count)} {incr ii} {
 	set key [string range $ianalysis(bind,$ii,item) 1 1]
-	append result "\#$ii bind"
+	append result "bind [expr $ii+1]"
 	append result "\nbind key $ianalysis(bind,$ii,item)"
 	append result "\n$ianalysis(bind,$ii,template)"
 	append result "\nbind $key"
@@ -2045,6 +2091,17 @@ proc AnalysisSendCmd {} {
 	append result "\n\n"
     }
 
+    for {set ii 0} {$ii<$ianalysis(buttonbar,count)} {incr ii} {
+	for {set jj 0} {$jj<$ianalysis(buttonbar,$ii,count)} {incr jj} {
+	    append result "buttonbar [expr $ii+1]"
+	    append result "\n$ianalysis(buttonbar,$ii-$jj,item)"
+	    append result "\n$ianalysis(buttonbar,$ii-$jj,template)"
+	    append result "\nbutton"
+	    append result "\n$ianalysis(buttonbar,$ii-$jj,cmd)"
+	}
+	append result "\n\n"
+    }
+
     ProcessSend $parse(proc) $parse(id) $parse(sock) $parse(fn) {.ans} $result
 }
 
@@ -2058,6 +2115,13 @@ proc AnalysisSendCmdMessage {type txt} {
     ProcessSendCmdTxt [AnalysisMessage $type $txt]
 }
 
+proc AnalysisSendCmdFileDialog {which} {
+    switch $which {
+	open {ProcessSendCmdTxt [OpenFileDialog analysisparamfbox]}
+	save {ProcessSendCmdTxt [SaveFileDialog analysisparamfbox]}
+    }
+}
+
 proc AnalysisSendCmdTask {} {
     global ianalysis
 
