@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -21,18 +21,14 @@ proc Backup {fn} {
 	return
     }
     
-    # update any tags
-    if {$current(frame) != {}} {
-	$current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
-    }
+    # EditText Dialogs
+    EditTextUpdateVar
 
     # Panner
     PannerBackup $ch
 
     # Colorbar
-    ColorbarBackupCmaps $ch $dir
-    ColorbarBackup $ch colorbar
-    ColorbarBackup $ch colorbarrgb
+    ColorbarBackup $ch $dir
 
     # Frames
     foreach ff $ds9(frames) {
@@ -143,6 +139,7 @@ proc RestoreDialog {} {
 proc Restore {fn} {
     global ds9
     global pds9
+    global current
 
     if {[string length $fn] == 0} {
 	return
@@ -165,6 +162,12 @@ proc Restore {fn} {
 	SimpleTextDestroy $varname
     }
 
+    # kill all edit text dialogs
+    global iedittxt
+    foreach varname $iedittxt(dialogs) {
+	EditTextDestroy $varname
+    }
+
     # kill all cats
     global icat
     foreach varname $icat(cats) {
@@ -237,6 +240,15 @@ proc Restore {fn} {
     # fix any prefs
     FixPrefs $vv
 
+    # for old backup sets with one colorbar,
+    #   make sure each colorbar has the correct info from its frame
+    if {$vv <= {8.3}} {
+      foreach ff $ds9(frames) {
+	set cb ${ff}cb
+	$cb colorbar [$ff get colorbar]
+      }
+    }
+
     # reset standard dialog
     switch $ds9(wm) {
 	x11 {set pds9(dialog) motif}
@@ -248,8 +260,7 @@ proc Restore {fn} {
     cd $cd
 
     # and update it
-    UpdateGraphGrid
-    LayoutOrient
+    LayoutView
     UpdateActiveFrames
     ChangeMode
     UpdateDS9
@@ -285,8 +296,7 @@ proc BackupFrame {ch which dir} {
     }
 
     MagnifierFrameBackup $ch $which
-    ColorFrameBackup $ch $which
-    ColormapFrameBackup $ch $which
+    ColorbarFrameBackup $ch $which
 
     DS9Backup $ch $which
     CubeBackup $ch $which
@@ -297,6 +307,11 @@ proc BackupFrame {ch which dir} {
     BlockBackup $ch $which
     # WCS nees to be before Pan/Zoom
     WCSBackup $ch $which $fdir $rdir
+
+    # ok, at this point, we must realize the frame, so that all matrices
+    # are valid for pan/zoom/crosshair/markers etc...
+    puts $ch "update"
+
     PanZoomBackup $ch $which
     CropBackup $ch $which
     # must be after Pan and Block
@@ -536,6 +551,10 @@ proc BackupGUI {ch} {
 
     # Basic
 
+    global ds9notes
+    puts $ch "global ds9notes"
+    puts $ch "set ds9notes \{$ds9notes\}"
+
     global pds9
     puts $ch "global pds9"
     puts $ch "array set pds9 \{ [array get pds9] \}"
