@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -131,18 +131,17 @@ proc CATLoad {varname url query} {
     return
 }
 
-proc CATProcess {varname} {
+proc CATExec {varname} {
     upvar #0 $varname var
     global $varname
 
     global debug
     if {$debug(tcl,cat)} {
-	puts stderr "CATProcess $varname"
+	puts stderr "CATExec $varname"
     }
 
     VOTParse $var(catdb) $var(token)
     ARDone $varname
-
     CATLoadDone $varname
 }
 
@@ -393,7 +392,7 @@ proc CATLoadFn {varname fn reader} {
 	return
     }
 
-    ARDone $varname
+    ARStatus $varname [msgcat::mc {Done}]
     CATLoadDone $varname
 }
 
@@ -1063,8 +1062,11 @@ proc CatalogCmdMatchParams {cat1 cat2} {
 }
 
 proc CatalogCmdSAMP {} {
-    global cvarname
     global samp
+    global cvarname
+    if {$cvarname == {}} {
+	return
+    }
 
     if {[info exists samp]} {
 	SAMPSendTableLoadVotable {} $cvarname
@@ -1074,8 +1076,11 @@ proc CatalogCmdSAMP {} {
 }
 
 proc CatalogCmdSAMPSend {name} {
-    global cvarname
     global samp
+    global cvarname
+    if {$cvarname == {}} {
+	return
+    }
 
     if {[info exists samp]} {
 	foreach arg $samp(apps,votable) {
@@ -1093,6 +1098,9 @@ proc CatalogCmdSAMPSend {name} {
 
 proc CatalogCmdSkyframe {skyframe} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
 
     set cvar(sky) $skyframe
@@ -1101,6 +1109,9 @@ proc CatalogCmdSkyframe {skyframe} {
 
 proc CatalogCmdSystem {sys} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
 
     set cvar(system) $sys
@@ -1109,6 +1120,9 @@ proc CatalogCmdSystem {sys} {
 
 proc CatalogCmdSymbol {col value} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     global $cvar(symdb)
 
@@ -1119,6 +1133,9 @@ proc CatalogCmdSymbol {col value} {
 
 proc CatalogCmdSymbolFontStyle {value} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     global $cvar(symdb)
 
@@ -1147,6 +1164,9 @@ proc CatalogCmdSymbolFontStyle {value} {
 
 proc CatalogCmdSymbolAdd {} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     global $cvar(symdb)
 
@@ -1178,6 +1198,9 @@ proc CatalogCmdSymbolAdd {} {
 
 proc CatalogCmdSymbolRemove {} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     global $cvar(symdb)
 
@@ -1187,6 +1210,9 @@ proc CatalogCmdSymbolRemove {} {
 
 proc CatalogCmdSymbolLoad {fn} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     global $cvar(symdb)
 
@@ -1201,6 +1227,9 @@ proc CatalogCmdSymbolLoad {fn} {
 
 proc CatalogCmdSymbolSave {fn} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     global $cvar(symdb)
 
