@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -46,7 +46,7 @@ proc CATDialog {varname format catalog title action} {
     ARInit $varname CATServer
 
     # procs
-    set var(proc,process) CATProcess
+    set var(proc,exec) CATExec
     set var(proc,load) CATLoad
     set var(proc,error) ARError
     set var(proc,table) CATTable
@@ -142,7 +142,7 @@ proc CATDialog {varname format catalog title action} {
     $mb.file add command -label [msgcat::mc {Plot}] \
 	-command [list CATPlot $varname]
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Display Header}]..." \
+    $mb.file add command -label [msgcat::mc {Header}] \
 	-command [list CATHeader $varname]
     $mb.file add command -label [msgcat::mc {Acknowledgment}] \
 	-command [list CATAck $varname]
@@ -539,8 +539,7 @@ proc CATDialogUpdate {varname} {
 	$var(mb).file entryconfig [msgcat::mc {Filter}] -state normal
 	$var(mb).file entryconfig [msgcat::mc {Clear}] -state normal
 	$var(mb).file entryconfig [msgcat::mc {Plot}] -state normal
-	$var(mb).file entryconfig "[msgcat::mc {Display Header}]..." \
-	    -state normal
+	$var(mb).file entryconfig [msgcat::mc {Header}] -state normal
 	$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -state normal
 	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state normal
 
@@ -551,8 +550,7 @@ proc CATDialogUpdate {varname} {
 	$var(mb).file entryconfig [msgcat::mc {Filter}] -state disabled
 	$var(mb).file entryconfig [msgcat::mc {Clear}] -state disabled
 	$var(mb).file entryconfig [msgcat::mc {Plot}] -state disabled
-	$var(mb).file entryconfig "[msgcat::mc {Display Header}]..." \
-	    -state disabled
+	$var(mb).file entryconfig [msgcat::mc {Header}] -state disabled
 	$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -state disabled
 	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state disabled
 
@@ -769,33 +767,13 @@ proc CATEdit {varname} {
     }
 }
 
-proc CATGetHeader {varname} {
-    upvar #0 $varname var
-    global $varname
-    global $var(tbldb)
-
-    set t $var(tbldb)
-    upvar #0 $t T
-
-    if {![TBLValidDB $var(tbldb)]} {
-	return {}
-    }
-
-    set hdr {}
-    set nl [expr $T(HLines)-2]
-    for {set ll 1} {$ll <= $nl} {incr ll} {
-	append hdr "$T(H_$ll)\n"
-    }
-    return $hdr
-}
-
 proc CATHeader {varname} {
     upvar #0 $varname var
     global $varname
     global $var(tbldb)
 
     SimpleTextDialog ${varname}hdr "$var(title) [msgcat::mc {Header}]" \
-	80 20 insert top [CATGetHeader $varname]
+	80 20 insert top [TBLGetHeader $varname]
 }
 
 proc CATKey {which key} {
@@ -814,18 +792,6 @@ proc CATKey {which key} {
     set icat(key,update) {}
 }
 
-proc CATPageSetup {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global ds9
-    switch $ds9(wm) {
-	x11 -
-	aqua -
-	win32 {}
-    }
-}
-
 proc CATWCSMenuUpdate {varname} {
     upvar #0 $varname var
     global $varname
