@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -198,32 +198,38 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -gif {set file(type) gif}
 	    -green {set current(rgb) green; RGBChannel}
+	    -graph {incr i; ProcessGraphCmd argv i}
 	    -grid {incr i; ProcessGridCmd argv i}
 	    -nogrid {set grid(view) 0; GridUpdateCurrent}
 	    -header {incr i; ProcessHeaderCmd argv i}
 	    -height {incr i; ProcessHeightCmd argv i}
 	    -histequ {set scale(type) histequ; ChangeScale}
+	    -horizontal {
+		#backward compatibility
+		set view(layout) horizontal
+		LayoutView
+	    }
 	    -horzgraph {
 		# backward compatibility
 		set view(graph,horz) 1
-		UpdateView
+		LayoutView
 	    }
 	    -nohorzgraph {
 		# backward compatibility
 		set view(graph,horz) 0
-		UpdateView
+		LayoutView
 	    }
 	    -iconify {incr i; ProcessIconifyCmd argv i}
 	    -iis {incr i; ProcessIISCmd argv i}
 	    -info {
 		# backward compatibility
 		set view(info) 1
-		UpdateView
+		LayoutView
 	    }
 	    -noinfo {
 		# backward compatibility
 		set view(info) 0
-		UpdateView
+		LayoutView
 	    }
 	    -invert {set colorbar(invert) 1; InvertColorbar}
 	    -jpg -
@@ -240,7 +246,7 @@ proc ProcessCommand {argv argc} {
 	    -nomagnifier {
 		# backward compatibility
 		set view(magnifier) 0
-		UpdateView
+		LayoutView
 	    }
 	    -mask {incr i; set file(layer) [ProcessMaskCmd argv i]}
 	    -nomask {set file(layer) {}}
@@ -309,6 +315,8 @@ proc ProcessCommand {argv argc} {
 		incr i
 		ProcessNanCmd argv i
 	    }
+	    -note -
+	    -notes {incr i; ProcessNotesCmd argv i}
 	    -nrrd {set file(type) nrrd}
 	    -nvss {incr i; ProcessNVSSCmd argv i}
 	    -orient {incr i; ProcessOrientCmd argv i}
@@ -318,12 +326,12 @@ proc ProcessCommand {argv argc} {
 	    -panner {
 		# backward compatibility
 		set view(panner) 1
-		UpdateView
+		LayoutView
 	    }
 	    -nopanner {
 		# backward compatibility
 		set view(panner) 0
-		UpdateView
+		LayoutView
 	    }
 	    -photo {
 		# backward compatibility
@@ -349,8 +357,8 @@ proc ProcessCommand {argv argc} {
 	    -pow {set scale(type) pow; ChangeScale}
 	    -prefs {incr i; ProcessPrefsCmd argv i}
 	    -preserve {incr i; ProcessPreserveCmd argv i}
-	    -print {incr i; ProcessPrintCmd argv i}
-	    -psprint {incr i; ProcessPSPrintCmd argv i}
+	    -print -
+	    -psprint {incr i; ProcessPrintCmd argv i}
 	    -private {
 		#already processed
 	    }
@@ -454,15 +462,20 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -url {set file(type) url}
 	    -update {incr i; ProcessUpdateCmd argv i}
+	    -vertical {
+		#backward compatibility
+		set view(layout) vertical
+		LayoutView
+	    }
 	    -vertgraph {
 		#backward compatibility
 		set view(graph,vert) 1
-		UpdateView
+		LayoutView
 	    }
 	    -novertgraph {
 		#backward compatibility
 		set view(graph,vert) 0
-		UpdateView
+		LayoutView
 	    }
 	    -view {incr i; ProcessViewCmd argv i}
 	    -visual {
