@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -334,7 +334,7 @@ proc UpdateCube {} {
     UpdateScaleDialog
     UpdateContourScale
     UpdateContourDialog
-    UpdateGraphAxis $current(frame)
+    UpdateGraphsAxis $current(frame)
     UpdateInfoBoxFrame $current(frame)
     UpdateMain
 }
