@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -13,9 +13,9 @@ proc DS9Def {} {
     }
 
     # Must be major,minor
-    set ds9(version) {8.2}
+    set ds9(version) {8.3}
     # For display purposes only
-    set ds9(version,display) {8.2}
+    set ds9(version,display) {8.3}
 
     set ds9(visual) {}
     set ds9(depth) 8
@@ -37,6 +37,7 @@ proc DS9Def {} {
 
     set ds9(helvetica) [font configure TkDefaultFont -family]
     set ds9(courier) [font configure TkFixedFont -family]
+    set ds9(courier) courier
     switch $ds9(wm) {
 	x11 {
 	    set ds9(times) serif
@@ -45,8 +46,14 @@ proc DS9Def {} {
 	    font configure TkCaptionFont -weight normal
 	    font configure TkHeadingFont -weight normal
 	}
-	aqua -
-	win32 {set ds9(times) times}
+	aqua {
+	    # bad system fonts returned by Mojave
+	    set ds9(helvetica) {.AppleSystemUIFont}
+	    set ds9(times) times
+	}	    
+	win32 {
+	    set ds9(times) times
+	}
     }
     set ds9(main) {}
     set ds9(image) {}
@@ -56,16 +63,11 @@ proc DS9Def {} {
     set ds9(panner) {}
     set ds9(magnifier) {}
     set ds9(buttons) {}
-    set ds9(graph,sp) {}
-    set ds9(graph,horz) {}
-    set ds9(graph,vert) {}
 
     set ds9(frames) {}
+    set ds9(seq) 1
     set ds9(active) {}
-    set ds9(active,num) 0
     set ds9(lock) 0
-    set ds9(next) {}
-    set ds9(next,num) 1
     set ds9(last) {}
 
     set ds9(event,opendoc) {}
@@ -80,7 +82,7 @@ proc DS9Def {} {
     }
     set ds9(menu,size,frame,goto) [expr $ds9(menu,start)+0]
     set ds9(menu,size,frame,active) [expr $ds9(menu,start)+3]
-    set ds9(menu,size,analysis) [expr $ds9(menu,start)+34]
+    set ds9(menu,size,analysis) [expr $ds9(menu,start)+36]
     set ds9(menu,size,wrap) 20
 
     set ds9(display) single
@@ -230,11 +232,14 @@ switch $ds9(wm) {
 	package require colorutils
 	package require awdark
 	package require awlight
+	package require awarc
 	package require awblack
-#	package require awwinxpblue
 	package require awbreeze
+	package require awbreezedark
+	package require awclearlooks
+	package require awwinxpblue
 
-	# tkthemes- alot of these lacks full set of colors
+	# ttkthemes- alot of these lacks full set of colors
 #	package require ttk::theme::aquativo
 #	package require ttk::theme::black
 #	package require ttk::theme::blue
@@ -342,7 +347,6 @@ AnalysisDef
 BinDef
 BlinkDef
 BlockDef
-ButtonsDef
 CanvasDef
 CATDef
 CATSymDef
@@ -374,6 +378,7 @@ MarkerDef
 MaskDef
 MinMaxDef
 MovieDef
+NotesDef
 NRESDef
 NVSSDef
 PannerDef
@@ -391,6 +396,7 @@ SaveImageDef
 ScaleDef
 SIADef
 SimpleTextDef
+EditTextDef
 SkyViewDef
 SmoothDef
 STSCIDef
@@ -402,6 +408,8 @@ VLSSDef
 VODef
 WCSDef
 ZScaleDef
+# do last
+ButtonsDef
 
 # let's start
 set ds9(init) 1
@@ -528,13 +536,7 @@ switch $pds9(language) {
 		    }
 		}
 	    }
-	    aqua {
-		foreach ll [MacOSXGetLocale] {
-		    if {[SetLanguage $ll]} {
-			break
-		    }
-		}
-	    }
+	    aqua {}
 	    win32 {}
 	}
     }
@@ -557,13 +559,14 @@ CreateInfoPanel
 CreatePanner
 CreateMagnifier
 CreateButtons
-CreateGraphs
+
+# Create default Graphs
+GraphsCreate graph
 
 # Make sure that the wm knows when to swap in the colormap (if needed)
 wm colormapwindows . "$ds9(main) $ds9(canvas)"
 
 # Initialize the display
-InitColorbar
 InitPanner
 InitDialogBox
 
@@ -577,13 +580,13 @@ if {$debug(tcl,idletasks)} {
 }
 update
 
-# layout
-ConfigureView
+# layout before first frame
+LayoutView
 
 # our first frame
 CreateFrame
 
-# do this last so we don't get an ConfigureView event
+# do this last so we don't get an LayoutView event
 InitCanvas
 
 # ok, ready to show the window
@@ -633,39 +636,31 @@ SourceInitFileDir {.ini}
 # do we have the correct prefs file?
 CheckPrefs
 
-# kludge for aqua. We need to trigger the trap to update buttons vars
-switch $ds9(wm) {
-    x11 -
-    win32 {}
-    aqua {
-	set current(display) $current(display)
-	set colorbar(map) $colorbar(map)
-    }
-}
-
 # start error monitor
 after $ds9(msg,timeout) [list ErrorTimer]
 
 # ok, we're done
 set ds9(init) 0
 
-# everything must be realized
-update
-
 # major kludges
 switch $ds9(wm) {
     x11 {
+        # everything must be realized
+        update
+
 	# be sure theme has been set
 	# could be changed in prefs or command line
 	ThemeChange
 
-	# lock down geometry at statup
-	# so unneeded configure events are not generated
-	# a problem with recent versions of linux
-	wm geometry $ds9(top) \
-	    "[winfo width $ds9(top)]x[winfo height $ds9(top)]"
+       # lock down geometry at statup
+       # so no resize top window configure events are generated
+       wm geometry $ds9(top) "[winfo width $ds9(top)]x[winfo height $ds9(top)]"
     }
+    aqua {}
     win32 {
+        # everything must be realized
+        update
+
 	# default for win32
 	if {$pds9(theme) == {default}} {
 	    set pds9(theme) xpnative
@@ -676,5 +671,4 @@ switch $ds9(wm) {
 	# jump start keyevents for windows
 	event generate $ds9(canvas) <Tab> -x 0 -y 0
     }
-    aqua {}
 }
