@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -23,17 +23,8 @@ proc Create3DFrame {} {
 proc CreateNamedFrame {type} {
     global ds9
 
-    # find the first open slot
-    set num $ds9(next,num)
-    while {1} {
-	set which "Frame$num"
- 	if {[lsearch $ds9(frames) $which]==-1} {
- 	    CreateNameNumberFrame $which $type
-	    set ds9(next,num) [expr $num+1]
- 	    return
- 	}
- 	incr num
-    }
+    CreateNameNumberFrame "Frame$ds9(seq)" $type
+    incr ds9(seq)
 }
 
 proc CreateGotoFrame {num type} {
@@ -43,14 +34,13 @@ proc CreateGotoFrame {num type} {
     set which "Frame$num"
     if {[lsearch $ds9(frames) $which]==-1} {
 	CreateNameNumberFrame $which $type
-	set ds9(next,num) [expr $num+1]
+	set ds9(seq) [expr $num+1]
     } else {
 	if {$active($which)==0} {
 	    set active($which) 1
 	    UpdateActiveFrames
 	}
-	set ds9(next) $which
-	GotoFrame
+	GotoFrame $which
     }
 }
 
@@ -81,127 +71,124 @@ proc CreateNameNumberFrame {which type} {
     global threed
     global cube
 
-    set ds9(next) $which
-
     # update frame lists
-    lappend ds9(frames) $ds9(next)
-    lappend ds9(active) $ds9(next)
-    set ds9(active,num) [llength $ds9(active)]
-    set active($ds9(next)) 1
+    lappend ds9(frames) $which
+    lappend ds9(active) $which
+    set active($which) 1
 
     # and create the frame
     switch -- $type {
 	base {
 	    $ds9(canvas) create frame$ds9(visual)$ds9(depth) \
-		-command $ds9(next)
-	    $ds9(next) colormap [colorbar get colormap]
+		-command $which
+	    CreateColorbarBase $which
 	}
 	rgb {
 	    $ds9(canvas) create framergb$ds9(visual)$ds9(depth) \
-		-command $ds9(next)
-	    $ds9(next) colormap [colorbarrgb get colormap]
+		-command $which
+	    CreateColorbarRGB $which
 	}
 	3d {
 	    $ds9(canvas) create frame3d$ds9(visual)$ds9(depth) \
-		-command $ds9(next)
-	    $ds9(next) colormap [colorbar get colormap]
+		-command $which
+	    CreateColorbarBase $which
 	}
     }
-
-    $ds9(next) configure -x 0 -y 0 \
+    GraphsCreate $which
+    
+    $which configure -x 0 -y 0 \
 	-anchor nw \
-	-tag $ds9(next) \
+	-tag $which \
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
 	-times $ds9(times) \
 	-fg [ThemeTreeForeground] \
 	-bg [ThemeTreeBackground]
 
-    $ds9(next) threads $ds9(threads)
+    $which threads $ds9(threads)
 
-    $ds9(next) panner 'panner' $ipanner(size) $ipanner(size)
-    $ds9(next) magnifier 'magnifier' $imagnifier(size) $imagnifier(size)
-    $ds9(next) magnifier zoom $pmagnifier(zoom)
-    $ds9(next) magnifier graphics $pmagnifier(region)
-    $ds9(next) magnifier cursor $pmagnifier(cursor)
+    $which panner 'panner' $ipanner(size) $ipanner(size)
+    $which magnifier 'magnifier' $imagnifier(size) $imagnifier(size)
+    $which magnifier zoom $pmagnifier(zoom)
+    $which magnifier graphics $pmagnifier(region)
+    $which magnifier cursor $pmagnifier(cursor)
 
-    $ds9(next) zoom to $current(zoom)
-    $ds9(next) rotate to $current(rotate)
-    $ds9(next) orient $current(orient)
-    $ds9(next) wcs align $current(align)
+    $which zoom to $current(zoom)
+    $which rotate to $current(rotate)
+    $which orient $current(orient)
+    $which wcs align $current(align)
 
-    $ds9(next) pan preserve $panzoom(preserve)
+    $which pan preserve $panzoom(preserve)
 
     # set so prefs (pwcs) will work
     # may cause other problems, but can't remember why
-    $ds9(next) wcs $wcs(system) $wcs(sky) $wcs(skyformat)
+    $which wcs $wcs(system) $wcs(sky) $wcs(skyformat)
 
-    $ds9(next) datasec $scale(datasec)
+    $which datasec $scale(datasec)
 
-    $ds9(next) precision $pds9(prec,linear) $pds9(prec,deg) \
+    $which precision $pds9(prec,linear) $pds9(prec,deg) \
 	$pds9(prec,hms) $pds9(prec,dms) \
 	$pds9(prec,len,linear) $pds9(prec,len,deg) \
 	$pds9(prec,len,arcmin) $pds9(prec,len,arcsec) \
 	$pds9(prec,angle)
     
-    $ds9(next) bg color $pds9(bg)
-    $ds9(next) bg color $pds9(bg,use)
-    $ds9(next) nan color $pds9(nan)
-    $ds9(next) highlite color blue
+    $which bg color $pds9(bg)
+    $which bg color $pds9(bg,use)
+    $which nan color $pds9(nan)
+    $which highlite color blue
 
-    $ds9(next) iraf align $pds9(iraf)
+    $which iraf align $pds9(iraf)
 
-    $ds9(next) marker epsilon $pmarker(epsilon)
-    $ds9(next) marker show $marker(show)
-    $ds9(next) marker show text $marker(show,text)
-    $ds9(next) marker centroid auto $marker(centroid,auto)
-    $ds9(next) marker centroid radius $marker(centroid,radius)
-    $ds9(next) marker centroid iteration $marker(centroid,iteration)
-    $ds9(next) marker preserve $marker(preserve)
+    $which marker epsilon $pmarker(epsilon)
+    $which marker show $marker(show)
+    $which marker show text $marker(show,text)
+    $which marker centroid auto $marker(centroid,auto)
+    $which marker centroid radius $marker(centroid,radius)
+    $which marker centroid iteration $marker(centroid,iteration)
+    $which marker preserve $marker(preserve)
 
     # Frame type items
-    switch -- [$ds9(next) get type] {
+    switch -- [$which get type] {
 	base {}
-	rgb {$ds9(next) rgb system $rgb(system)}
+	rgb {$which rgb system $rgb(system)}
 	3d {
-	    $ds9(next) 3d method $pthreed(method)
-	    $ds9(next) 3d background $pthreed(background)
-	    $ds9(next) 3d border $pthreed(border)
-	    $ds9(next) 3d border color $pthreed(border,color)
-	    $ds9(next) 3d compass $pthreed(compass)
-	    $ds9(next) 3d compass color $pthreed(compass,color)
-	    $ds9(next) 3d highlite $pthreed(highlite)
-	    $ds9(next) 3d highlite color $pthreed(highlite,color)
+	    $which 3d method $pthreed(method)
+	    $which 3d background $pthreed(background)
+	    $which 3d border $pthreed(border)
+	    $which 3d border color $pthreed(border,color)
+	    $which 3d compass $pthreed(compass)
+	    $which 3d compass color $pthreed(compass,color)
+	    $which 3d highlite $pthreed(highlite)
+	    $which 3d highlite color $pthreed(highlite,color)
 	}
     }
 
     # channel dependent items
-    switch -- [$ds9(next) get type] {
+    switch -- [$which get type] {
 	base -
 	3d {
-	    $ds9(next) colorscale $scale(type)
-	    $ds9(next) colorscale log $scale(log)
+	    $which colorscale $scale(type)
+	    $which colorscale log $scale(log)
 
-	    $ds9(next) clip scope $scale(scope)
-	    $ds9(next) clip mode $scale(mode)
-	    $ds9(next) clip minmax $minmax(sample) $minmax(mode)
-	    $ds9(next) clip user $scale(min) $scale(max)
-	    $ds9(next) clip zscale \
-		$zscale(contrast) $zscale(sample) $zscale(line)
+	    $which clip scope $scale(scope)
+	    $which clip mode $scale(mode)
+	    $which clip minmax $minmax(sample) $minmax(mode)
+	    $which clip user $scale(min) $scale(max)
+	    $which clip zscale $zscale(contrast) $zscale(sample) $zscale(line)
 
-	    $ds9(next) datasec $scale(datasec)
+	    $which datasec $scale(datasec)
 
-	    $ds9(next) bin function $bin(function)
-	    $ds9(next) bin factor to $bin(factor)
-	    $ds9(next) bin depth $bin(depth)
-	    $ds9(next) bin buffer size $bin(buffersize)
+	    $which bin function $bin(function)
+	    $which bin factor to $bin(factor)
+	    $which bin depth $bin(depth)
+	    $which bin buffer size $bin(buffersize)
 
-	    $ds9(next) block to $block(factor)
+	    $which block to $block(factor)
 	    
-	    $ds9(next) cube axes $cube(axes)
+	    $which cube axes $cube(axes)
 	    
 	    if {$smooth(view)} {
-		$ds9(next) smooth $smooth(function) \
+		$which smooth $smooth(function) \
 		    $smooth(radius) $smooth(radius,minor) \
 		    $smooth(sigma) $smooth(sigma,minor) \
 		    $smooth(angle)
@@ -209,51 +196,56 @@ proc CreateNameNumberFrame {which type} {
 	}
 	rgb {
 	    foreach c {red green blue} {
-		$ds9(next) rgb channel $c
+		$which rgb channel $c
 
-		$ds9(next) colorscale $scale(type)
-		$ds9(next) colorscale log $scale(log)
+		$which colorscale $scale(type)
+		$which colorscale log $scale(log)
 
-		$ds9(next) clip scope $scale(scope)
-		$ds9(next) clip mode $scale(mode)
-		$ds9(next) clip minmax $minmax(sample) $minmax(mode)
-		$ds9(next) clip user $scale(min) $scale(max)
-		$ds9(next) clip zscale \
+		$which clip scope $scale(scope)
+		$which clip mode $scale(mode)
+		$which clip minmax $minmax(sample) $minmax(mode)
+		$which clip user $scale(min) $scale(max)
+		$which clip zscale \
 		    $zscale(contrast) $zscale(sample) $zscale(line)
 
-		$ds9(next) datasec $scale(datasec)
+		$which datasec $scale(datasec)
 
-		$ds9(next) bin function $bin(function)
-		$ds9(next) bin factor to $bin(factor)
-		$ds9(next) bin depth $bin(depth)
-		$ds9(next) bin buffer size $bin(buffersize)
+		$which bin function $bin(function)
+		$which bin factor to $bin(factor)
+		$which bin depth $bin(depth)
+		$which bin buffer size $bin(buffersize)
 
-		$ds9(next) block to $block(factor)
+		$which block to $block(factor)
 
-		$ds9(next) cube axes $cube(axes)
+		$which cube axes $cube(axes)
 
 		if {$smooth(view)} {
-		    $ds9(next) smooth $smooth(function) \
+		    $which smooth $smooth(function) \
 			$smooth(radius) $smooth(radius,minor) \
 			$smooth(sigma) $smooth(sigma,minor) \
 			$smooth(angle)
 		}
 	    }
-	    $ds9(next) rgb channel red
+	    $which rgb channel red
 	}
     }
 
+    # enable events
+    BindEventsFrame $which
+    
     switch $current(mode) {
-	crosshair {$ds9(next) crosshair on}
+	crosshair {$which crosshair on}
     }
 
     UpdateFrameMenuItems
 
-    if {$current(frame) != {}} {
-	$current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
-    }
-    set current(frame) $ds9(next)
-    set ds9(next) {}
+    # update frame colormap
+    $which colormap [${which}cb get colormap]
+
+    # set to current frame
+    set current(frame) $which
+    set current(colorbar) ${which}cb
+
     DisplayMode
 }
 
@@ -283,14 +275,13 @@ proc DeleteAllFrames {} {
 	DeleteFrame $ff
     }
 
-    set ds9(next,num) 1
+    set ds9(seq) 1
 
     UpdateFrameMenuItems
     UpdateActiveFrames
 
     ClearInfoBox
     PixelTableClearDialog
-    ClearGraphData
 }
 
 proc DeleteSingleFrame {which} {
@@ -300,7 +291,6 @@ proc DeleteSingleFrame {which} {
     UpdateActiveFrames
 
     PixelTableClearDialog
-    ClearGraphData
 }
 
 proc DeleteFrame {which} {
@@ -322,18 +312,29 @@ proc DeleteFrame {which} {
 	set marker(copy) {}
     }
     
+    # delete canvas colorbar
+    $ds9(canvas) delete ${which}cb
+
+    # delete canvas graphs
+    GraphsDelete $which
+
     # delete canvas widget
     $ds9(canvas) delete $which
 
-    # setup for next frame
+    # reset current(frame) if needed
+    if {$current(frame) == $which} {
+	set ii [lsearch $ds9(active) $which]
+	if {$ii>0} {
+	    set current(frame) [lindex $ds9(active) [expr $ii-1]]
+	    set current(colorbar) ${current(frame)}cb
+	}
+    }
+
+    # delete it from active list
     set ii [lsearch $ds9(active) $which]
     if {$ii>0} {
-	set ds9(next) [lindex $ds9(active) [expr $ii-1]]
 	set ds9(active) [lreplace $ds9(active) $ii $ii]
-	set ds9(active,num) [llength $ds9(active)]
 	unset active($which)
-    } else {
-	set ds9(next) {}
     }
 
     # delete it from the frame list
@@ -350,8 +351,8 @@ proc UpdateCurrentFrame {} {
 proc UpdateAllFrame {} {
     global ds9
 
-    foreach f $ds9(frames) {
-	UpdateFrame $f
+    foreach ff $ds9(frames) {
+	UpdateFrame $ff
     }
 }
 
@@ -557,7 +558,7 @@ proc EnterFrame {which x y} {
 
     global debug
     if {$debug(tcl,events)} {
-	puts stderr "EnterFrame $which"
+	puts stderr "EnterFrame $which $x $y"
     }
 
     # check to see if this event was generated while processing other events
@@ -592,9 +593,9 @@ proc EnterFrame {which x y} {
     EnterInfoBox $which
     UpdateInfoBox $which $x $y canvas
     UpdatePixelTableDialog $which $x $y canvas
-    UpdateGraphLayout $which
-    UpdateGraphAxis $which
-    UpdateGraphData $which $x $y canvas
+
+    ShowGraphsData $which
+    UpdateGraphsData $which $x $y canvas
 
     if {$view(magnifier)} {
 	# don't turn on the magnifier until we've finished the init process
@@ -641,7 +642,7 @@ proc LeaveFrame {which} {
 	3d {
 	    LeaveInfoBox
 	    PixelTableClearDialog
-	    ClearGraphData
+	    HideGraphsData $which
 	}
 	crosshair {}
     }
@@ -698,7 +699,7 @@ proc DoMotion {which x y cursor1 cursor2} {
 	    UpdateColormapLevelMosaic $which $x $y canvas
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
-	    UpdateGraphData $which $x $y canvas
+	    UpdateGraphsData $which $x $y canvas
 	}
 	none -
 	colorbar -
@@ -712,7 +713,7 @@ proc DoMotion {which x y cursor1 cursor2} {
 	    UpdateColormapLevelMosaic $which $x $y canvas
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
-	    UpdateGraphData $which $x $y canvas
+	    UpdateGraphsData $which $x $y canvas
 	}
 	crosshair {}
     }
@@ -742,8 +743,7 @@ proc Button1Frame {which x y} {
 		set imarker(motion) none
 		set imarker(handle) -1
 
-		set ds9(next) $which
-		GotoFrame
+		GotoFrame $which
 	    }
 	}
 	pointer -
@@ -756,8 +756,7 @@ proc Button1Frame {which x y} {
 		set imarker(motion) none
 		set imarker(handle) -1
 
-		set ds9(next) $which
-		GotoFrame
+		GotoFrame $which
 	    }
 	}
 	crosshair {
@@ -766,18 +765,20 @@ proc Button1Frame {which x y} {
 	    UpdateColormapLevelMosaic $which $x $y canvas
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
-	    UpdateGraphLayout $which
-	    UpdateGraphAxis $which
-	    UpdateGraphData $which $x $y canvas
+	    UpdateGraphsData $which $x $y canvas
+	}
+	colorbar {
+	    ColorbarButton3 $which $x $y
 	}
-	colorbar {ColorbarButton3 $x $y}
 	pan {
 	    PanButton $which $x $y
 	}
 	zoom {
 	    ZoomButton $which $x $y
 	}
-	rotate {RotateButton $which $x $y}
+	rotate {
+	    RotateButton $which $x $y
+	}
 	crop {
 	    CropButton $which $x $y
 	}
@@ -790,8 +791,7 @@ proc Button1Frame {which x y} {
 		set imarker(motion) none
 		set imarker(handle) -1
 
-		set ds9(next) $which
-		GotoFrame
+		GotoFrame $which
 	    }
 	}
         footprint {
@@ -803,12 +803,15 @@ proc Button1Frame {which x y} {
                 set imarker(motion) none
                 set imarker(handle) -1
 
-                set ds9(next) $which
-                GotoFrame
+                GotoFrame $which
             }
         }
-	examine {ExamineButton $which $x $y}
-	iexam {IExamButton $which $x $y}
+	examine {
+	    ExamineButton $which $x $y
+	}
+	iexam {
+	    IExamButton $which $x $y
+	}
 	3d {}
     }
 }
@@ -836,7 +839,9 @@ proc ShiftButton1Frame {which x y} {
 	crosshair {}
 	colorbar {}
 	pan {}
-	zoom {ZoomShift $which}
+	zoom {
+	    ZoomShift $which
+	}
 	rotate -
 	crop {
 	    Crop3dButton $which $x $y 0
@@ -966,7 +971,7 @@ proc Motion1Frame {which x y} {
 
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
-	    UpdateGraphData $which $x $y canvas
+	    UpdateGraphsData $which $x $y canvas
 	}
 	crosshair {
 	    if {$ds9(b1)} {
@@ -975,12 +980,12 @@ proc Motion1Frame {which x y} {
 		UpdateColormapLevelMosaic $which $x $y canvas
 		UpdateInfoBox $which $x $y canvas
 		UpdatePixelTableDialog $which $x $y canvas
-		UpdateGraphData $which $x $y canvas
+		UpdateGraphsData $which $x $y canvas
 	    }
 	}
 	colorbar {
 	    if {$ds9(b1)} {
-		ColorbarMotion3 $x $y
+		ColorbarMotion3 $which $x $y
 	    }
 	}
 	pan {
@@ -1012,7 +1017,7 @@ proc Motion1Frame {which x y} {
 
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
-	    UpdateGraphData $which $x $y canvas
+	    UpdateGraphsData $which $x $y canvas
 	}
         footprint {
             if {$which == $current(frame)} {
@@ -1021,7 +1026,7 @@ proc Motion1Frame {which x y} {
 
             UpdateInfoBox $which $x $y canvas
             UpdatePixelTableDialog $which $x $y canvas
-            UpdateGraphData $which $x $y canvas
+            UpdateGraphsData $which $x $y canvas
         }
 	examine {}
 	iexam {}
@@ -1065,12 +1070,11 @@ proc Release1Frame {which x y} {
 		UpdateColormapLevelMosaic $which $x $y canvas
 		UpdateInfoBox $which $x $y canvas
 		UpdatePixelTableDialog $which $x $y canvas
-		UpdateGraphData $which $x $y canvas
 	    }
 	}
 	colorbar {
 	    if {$ds9(b1)} {
-		ColorbarRelease3 $x $y
+		ColorbarRelease3 $which $x $y
 	    }
 	}
 	pan {
@@ -1145,7 +1149,9 @@ proc Double1Frame {which x y} {
 	footprint -
 	examine -
 	iexam {}
-	3d {3DDouble $which}
+	3d {
+	    3DDouble $which
+	}
 	    
     }
 }
@@ -1542,8 +1548,8 @@ proc UndoFrame {} {
 
 proc FirstFrame {} {
     global ds9
-    set ds9(next) [lindex $ds9(active) 0]
-    GotoFrame
+
+    GotoFrame [lindex $ds9(active) 0]
 }
 
 proc PrevFrame {} {
@@ -1552,11 +1558,10 @@ proc PrevFrame {} {
 
     set ii [lsearch $ds9(active) $current(frame)]
     if {$ii>0} {
-	set ds9(next) [lindex $ds9(active) [expr $ii-1]]
+	GotoFrame [lindex $ds9(active) [expr $ii-1]]
     } else {
-	set ds9(next) [lindex $ds9(active) [expr $ds9(active,num)-1]]
+	GotoFrame [lindex $ds9(active) [expr [llength $ds9(active)]-1]]
     }
-    GotoFrame
 }
 
 proc NextFrame {} {
@@ -1564,19 +1569,17 @@ proc NextFrame {} {
     global current
 
     set ii [lsearch $ds9(active) $current(frame)]
-    if {$ii < [expr $ds9(active,num)-1]} {
-	set ds9(next) [lindex $ds9(active) [expr $ii+1]]
+    if {$ii < [expr [llength $ds9(active)]-1]} {
+	GotoFrame [lindex $ds9(active) [expr $ii+1]]
     } else {
-	set ds9(next) [lindex $ds9(active) 0]
+	GotoFrame [lindex $ds9(active) 0]
     }
-    GotoFrame
 }
 
 proc LastFrame {} {
     global ds9
 
-    set ds9(next) [lindex $ds9(active) [expr $ds9(active,num)-1]]
-    GotoFrame
+    GotoFrame [lindex $ds9(active) [expr [llength $ds9(active)]-1]]
 }
 
 proc MoveFirstFrame {} {
@@ -1648,30 +1651,23 @@ proc UpdateActiveFrames {} {
 
     # reset active list
     set ds9(active) {}
-    set ds9(active,num) 0
 
-    foreach f $ds9(frames) {
-	if {$active($f)} {
-	    lappend ds9(active) $f
+    foreach ff $ds9(frames) {
+	if {$active($ff)} {
+	    lappend ds9(active) $ff
 	    $ds9(mb).frame.goto entryconfig \
-		"[msgcat::mc {Frame}] [string range $f 5 end]" -state normal
+		"[msgcat::mc {Frame}] [string range $ff 5 end]" -state normal
 	} else {
 	    $ds9(mb).frame.goto entryconfig \
-		"[msgcat::mc {Frame}] [string range $f 5 end]" -state disabled
+		"[msgcat::mc {Frame}] [string range $ff 5 end]" -state disabled
 	}
-
     }
-    set ds9(active,num) [llength $ds9(active)]
 
     # New layout if needed
-    if {$ds9(active,num) > 0} {
+    if {[llength $ds9(active)] > 0} {
 	if {[lsearch $ds9(active) $current(frame)] == -1} {
-	    if {$ds9(next) != {}} {
-		set current(frame) $ds9(next)
-	    } else {
-		set current(frame) [lindex $ds9(active) 0]
-		set ds9(next) $current(frame)
-	    }
+	    set current(frame) [lindex $ds9(active) 0]
+	    set current(colorbar) ${current(frame)}cb
 	}
     }
 
@@ -1698,31 +1694,63 @@ proc ActiveFrameNone {} {
     UpdateActiveFrames
 }
 
-proc GotoFrame {} {
+proc GotoFrame {which} {
     global ds9
     global current
     global active
+    global view
 
-    if {$current(frame) != {} && $current(frame) != $ds9(next)} {
+    if {$current(frame) != {} && $current(frame) != $which} {
 	$current(frame) highlite off
 	$current(frame) panner off
 
 	switch -- $ds9(display) {
 	    blink -
 	    single {
-		$current(frame) hide
-		UnBindEventsFrame $current(frame)
+		set ff $current(frame)
+		# frame
+		$ff hide
+
+		# colorbar
+		if {$view(colorbar)} {
+		    ${ff}cb hide
+		}
+
+		# graphs
+		if {$view(graph,horz)} {
+		    GraphHide $ff horz
+		}
+		if {$view(graph,vert)} {
+		    GraphHide $ff vert
+		}
+		
 	    }
 	    tile {}
 	}
     }
 
-    if {$current(frame) != $ds9(next)} {
-	if {$current(frame) != {}} {
-	    $current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
+    if {$current(frame) != $which} {
+	set current(frame) $which
+	set current(colorbar) ${current(frame)}cb
+
+	# frame
+	$current(frame) show
+	$ds9(canvas) raise $current(frame)
+
+	# colorbar
+	if {$view(colorbar)} {
+	    $current(colorbar) show
+	    $ds9(canvas) raise $current(colorbar)
 	}
-	set current(frame) $ds9(next)
-	set ds9(next) {}
+
+	# graphs
+	if {$view(graph,horz)} {
+	    GraphShow $current(frame) horz
+	}
+	if {$view(graph,vert)} {
+	    GraphShow $current(frame) vert
+	}
+
 	FrameToFront
     }
 }
@@ -1737,7 +1765,7 @@ proc DisplayMode {} {
     switch -- $current(display) {
 	single {set ds9(display) $current(display)}
 	tile {
-	    if {$ds9(active,num) > 1} {
+	    if {[llength $ds9(active)] > 1} {
 		set ds9(display) $current(display)
 	    } else {
 		switch -- $tile(grid,mode) {
@@ -1747,7 +1775,7 @@ proc DisplayMode {} {
 	    }
 	}
 	blink {
-	    if {$ds9(active,num) > 1} {
+	    if {[llength $ds9(active)] > 1} {
 		set ds9(display) $current(display)
 	    } else {
 		set ds9(display) single
@@ -1782,13 +1810,12 @@ proc BlinkTimer {} {
     global iblink
     global ds9
 
-    if {$ds9(active,num) > 0} {
+    if {[llength $ds9(active)] > 0} {
 	incr iblink(index)
-	if {$iblink(index) >= $ds9(active,num)} {
+	if {$iblink(index) >= [llength $ds9(active)]} {
 	    set iblink(index) 0
 	}
-	set ds9(next) [lindex $ds9(active) $iblink(index)]
-	GotoFrame
+	GotoFrame [lindex $ds9(active) $iblink(index)]
     }
 
     set iblink(id) [after $blink(interval) BlinkTimer]
@@ -1818,7 +1845,6 @@ proc ResetFrame {which} {
 
 	RefreshInfoBox $which
 	PixelTableClearDialog
-	ClearGraphData
 
 	LockFrame $which
 	UpdatePanZoomDialog
@@ -1828,7 +1854,7 @@ proc ResetFrame {which} {
 	UpdateZoomMenu
 	UpdateScaleMenu
 	UpdateScaleDialog
-	UpdateGraphAxis $which
+	UpdateGraphsAxis $which
 
 	SAMPSendCoordPointAtSkyCmd $which
     }
@@ -1841,7 +1867,6 @@ proc ClearCurrentFrame {} {
 
     ClearInfoBox
     PixelTableClearDialog
-    ClearGraphData
 
     UpdateDS9
 }
@@ -1849,13 +1874,12 @@ proc ClearCurrentFrame {} {
 proc ClearAllFrame {} {
     global ds9
 
-    foreach f $ds9(frames) {
-	ClearFrame $f
+    foreach ff $ds9(frames) {
+	ClearFrame $ff
     }
 
     ClearInfoBox
     PixelTableClearDialog
-    ClearGraphData
 
     UpdateDS9
 }
@@ -1897,6 +1921,10 @@ proc ClearFrame {which} {
 
     DestroyHeader $which
     $which clear
+
+    # after unload
+    HideGraphsData $which
+    UpdateGraphsAxis $which
 }
 
 # Private Procedures
@@ -1906,79 +1934,21 @@ proc FrameToFront {} {
     global current
     global view
     global colorbar
-    global blink
 
-    set which $current(frame)
-
-    # process proper colorbar
-    switch -- [$which get type] {
-	base -
-	3d {
-	    if {$view(colorbar)} {
-		colorbar show
-	    } else {
-		colorbar hide
-	    }
-	    colorbarrgb hide
-	    set current(colorbar) colorbar
-
-	    colorbar colorbar [$which get colorbar]
-	    colorbar tag "\{[$which get colorbar tag]\}"
-	    set colorbar(map) [colorbar get name]
-
-	    $ds9(canvas) raise colorbar colorbarrgb
-	}
-	rgb {
-	    colorbar hide
-	    if {$view(colorbar)} {
-		colorbarrgb show
-	    } else {
-		colorbarrgb hide
-	    }
-	    set current(colorbar) colorbarrgb
-
-	    colorbarrgb colorbar [$which get colorbar]
-	    colorbarrgb rgb channel [$which get rgb channel]
-
-	    $ds9(canvas) raise colorbarrgb colorbar
-	}
-    }
+    set colorbar(map) [$current(colorbar) get name]
     set colorbar(invert) [$current(colorbar) get invert]
 
-    $ds9(canvas) raise $which
-
-    $which show
     switch -- $ds9(display) {
 	single -
-	blink {
-	    if {!$ds9(freeze)} {
-		BindEventsFrame $which
-	    }
-	}
-	tile {$which highlite on}
+	blink {}
+	tile {$current(frame) highlite on}
     }
 
     if {$view(panner)} {
-	$which panner on
+	$current(frame) panner on
     }
 
-    UpdateGraphLayout $which
     UpdateDS9
-
-    # Aqua has a problem with refreshing
-    switch $ds9(wm) {
-	x11 -
-	win32 {}
-	aqua {
-	    if {!$ds9(init)} {
-		global debug
-		if {$debug(tcl,idletasks)} {
-		    puts stderr "FrameToFront"
-		}
-		update idletasks
-	    }
-	}
-    }
 }
 
 proc TileDialog {} {
