@@ -1,3 +1,6 @@
+package provide DS9 1.0
+namespace eval ::http {}
+
 # Needed because some sites return 'x-fits' (CADC) in Content-Encoding
 proc http::ContentEncoding {token} {
     upvar 0 $token state
