@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -139,31 +139,37 @@ proc CreateInfoPanel {} {
 	-textvariable infobox(angle) -anchor center
 }
 
-proc LayoutFrameInfoBox {which type} {
+proc LayoutFrameInfoBox {which} {
     global view
 
     global debug
     if {$debug(tcl,events)} {
-	puts stderr "LayoutFrameInfoBox $which $type"
+	puts stderr "LayoutFrameInfoBox $which"
     }
 
     switch -- $view(layout) {
 	horizontal {
-	    LayoutFrameInfoBoxHorzValue $which $type
-	    LayoutFrameInfoBoxHorzWCS $which $type
-	    LayoutFrameInfoBoxHorzImage $which $type
+	    LayoutFrameInfoBoxHorzValue $which
+	    LayoutFrameInfoBoxHorzWCS $which
+	    LayoutFrameInfoBoxHorzImage $which
 	}
 	vertical {
-	    LayoutFrameInfoBoxVertValue $which $type
-	    LayoutFrameInfoBoxVertWCS $which $type
-	    LayoutFrameInfoBoxVertImage $which $type
+	    LayoutFrameInfoBoxVertValue $which
+	    LayoutFrameInfoBoxVertWCS $which
+	    LayoutFrameInfoBoxVertImage $which
 	}
     }
 }
 
-proc LayoutFrameInfoBoxHorzValue {which type} {
+proc LayoutFrameInfoBoxHorzValue {which} {
     global ds9
 
+    if {$which != {}} {
+	set type [$which get type]
+    } else {
+	set type base
+    }
+
     switch -- $type {
 	base -
 	3d {
@@ -193,7 +199,7 @@ proc LayoutFrameInfoBoxHorzValue {which type} {
     }
 }
 
-proc LayoutFrameInfoBoxHorzWCS {which type} {
+proc LayoutFrameInfoBoxHorzWCS {which} {
     global ds9
     global view
 
@@ -215,11 +221,17 @@ proc LayoutFrameInfoBoxHorzWCS {which type} {
     }
 }
 
-proc LayoutFrameInfoBoxHorzImage {which type} {
+proc LayoutFrameInfoBoxHorzImage {which} {
     global ds9
     global view
 
-    switch $type {
+    if {$which != {}} {
+	set type [$which get type]
+    } else {
+	set type base
+    }
+
+    switch -- $type {
 	base -
 	rgb {
 	    if {$which != {} && $view(info,image)} {
@@ -248,9 +260,15 @@ proc LayoutFrameInfoBoxHorzImage {which type} {
     }
 }
 
-proc LayoutFrameInfoBoxVertValue {which type} {
+proc LayoutFrameInfoBoxVertValue {which} {
     global ds9
 
+    if {$which != {}} {
+	set type [$which get type]
+    } else {
+	set type base
+    }
+
     switch -- $type {
 	base -
 	3d {
@@ -280,7 +298,7 @@ proc LayoutFrameInfoBoxVertValue {which type} {
     }
 }
 
-proc LayoutFrameInfoBoxVertWCS {which type} {
+proc LayoutFrameInfoBoxVertWCS {which} {
     global ds9
     global view
 
@@ -301,11 +319,17 @@ proc LayoutFrameInfoBoxVertWCS {which type} {
     }
 }
 
-proc LayoutFrameInfoBoxVertImage {which type} {
+proc LayoutFrameInfoBoxVertImage {which} {
     global ds9
     global view
 
-    switch $type {
+    if {$which != {}} {
+	set type [$which get type]
+    } else {
+	set type base
+    }
+
+    switch -- $type {
 	base -
 	rgb {
 	    if {$which != {} && $view(info,image)} {
@@ -342,7 +366,7 @@ proc EnterInfoBox {which} {
 	puts stderr "EnterInfoBox $which"
     }
 
-    LayoutFrameInfoBox $which [$which get type]
+    LayoutFrameInfoBox $which
     LayoutWCSInfoBox $which
 
     set infobox(frame) "[msgcat::mc {Frame}] [string range $which 5 end]"
@@ -583,7 +607,7 @@ proc LayoutInfoPanelHorz {} {
     # also adjust layout.tcl CanvasDef
     switch $ds9(wm) {
 	x11 {set xx 42}
-	aqua {set xx 40}
+	aqua -
 	win32 {set xx 40}
     }
 
@@ -815,7 +839,7 @@ proc LayoutInfoPanelHorz {} {
 	grid forget $ds9(info).imageYValue
     }
 
-    LayoutFrameInfoBox $current(frame) base
+    LayoutFrameInfoBox $current(frame)
 
     # frame, zoom, angle
     if {$view(info,frame)} {
@@ -1097,7 +1121,7 @@ proc LayoutInfoPanelVert {} {
 	grid forget $ds9(info).imageYValue
     }
 
-    LayoutFrameInfoBox $current(frame) base
+    LayoutFrameInfoBox $current(frame)
 
     # frame, zoom, angle
     if {$view(info,frame)} {
