@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -6,21 +6,14 @@ package provide DS9 1.0
 
 proc CanvasDef {} {
     global canvas
-    global icanvas
     global ds9
 
-    # also adjust info.tcl LayoutInfoPanelHorz
     switch $ds9(wm) {
-	x11 {set icanvas(horz,width) 738}
-	aqua {set icanvas(horz,width) 777}
-	win32 {set icanvas(horz,width) 740}
+	x11 {set canvas(width) 738}
+	aqua {set canvas(width) 777}
+	win32 {set canvas(width) 740}
     }
-
-    set icanvas(horz,height) 480
-    set icanvas(vert,width) 640
-    set icanvas(vert,height) 640
-    set canvas(width) $icanvas(horz,width)
-    set canvas(height) $icanvas(horz,height)
+    set canvas(height) 528
     set canvas(gap) 4
 
     switch $ds9(wm) {
@@ -33,7 +26,7 @@ proc CanvasDef {} {
 		default {set canvas(gap,bottom) 0}
 	    }
 	}
-	aqua {set canvas(gap,bottom) 14}
+	aqua  {set canvas(gap,bottom) 14}
 	win32 {set canvas(gap,bottom) 0}
     }
 }
@@ -74,6 +67,7 @@ proc ViewDef {} {
     global pview
 
     set view(layout) horizontal
+    set view(multi) 1
     set view(info) 1
     set view(panner) 1
     set view(magnifier) 1
@@ -108,17 +102,10 @@ proc CreateCanvas {} {
     global ds9
     global canvas
 
-    LayoutViewAdjust diff
-    set ww [expr $canvas(width)+$diff(x)]
-    set hh [expr $canvas(height)+$diff(y)]
-
-    global debug
-    if {$debug(tcl,layout)} {
-	puts stderr "CreateCanvas $canvas(width) $canvas(height) ${ww}x${hh}"
-    }
-
     set ds9(image) [ttk::frame $ds9(main).f]
-    set ds9(canvas) [canvas $ds9(image).c -width $ww -height $hh \
+    set ds9(canvas) [canvas $ds9(image).c \
+			 -width $canvas(width) \
+			 -height $canvas(height) \
 			 -highlightthickness 0 \
 			 -insertofftime 0 \
 			 -bg [ThemeTreeBackground] \
@@ -157,18 +144,20 @@ proc ThemeConfigCanvas {w} {
     $w itemconfigure colorbar -fg [ThemeTreeForeground]
     $w itemconfigure colorbar -bg [ThemeTreeBackground]
 
-    $w itemconfigure colorbarrgb -fg [ThemeTreeForeground]
-    $w itemconfigure colorbarrgb -bg [ThemeTreeBackground]
-
     foreach ff $ds9(frames) {
 	$w itemconfigure $ff -fg [ThemeTreeForeground]
 	$w itemconfigure $ff -bg [ThemeTreeBackground]
-    }
 
-    # since graphs are created, but maybe not realized
-    # must update manually
-    ThemeConfigGraph $ds9(graph,horz)
-    ThemeConfigGraph $ds9(graph,vert)
+	$w itemconfigure ${ff}cb -fg [ThemeTreeForeground]
+	$w itemconfigure ${ff}cb -bg [ThemeTreeBackground]
+
+	# since graphs are created, but maybe not realized
+	# must update manually
+	set varname ${ff}gr
+	global $varname
+	ThemeConfigGraph [subst $${varname}(horz)]
+	ThemeConfigGraph [subst $${varname}(vert)]
+    }
 }
 
 proc InitCanvas {} {
@@ -183,7 +172,7 @@ proc InitCanvas {} {
 	win32 {}
     }
 
-    bind $ds9(canvas) <Configure> [list ConfigureView]
+    bind $ds9(canvas) <Configure> [list LayoutView]
 
     # keyboard focus
     switch $ds9(wm) {
@@ -227,6 +216,7 @@ proc InitCanvas {} {
 
 proc Button3Canvas {x y} {
     global ds9
+    global current
 
     global debug
     if {$debug(tcl,events)} {
@@ -234,124 +224,60 @@ proc Button3Canvas {x y} {
     }
 
     set ds9(b3) 1
-    ColorbarButton3 $x $y
+    if {$current(frame) != {}} {
+	ColorbarButton3 $current(frame) $x $y
+    }
 }
 
 proc Motion3Canvas {x y} {
+    global ds9
+    global current
+
     global debug
     if {$debug(tcl,events)} {
 	puts stderr "Motion3Canvas"
     }
 
-    ColorbarMotion3 $x $y
+    if {$current(frame) != {}} {
+	ColorbarMotion3 $current(frame) $x $y
+    }
 }
 
 proc Release3Canvas {x y} {
     global ds9
+    global current
+
     global debug
     if {$debug(tcl,events)} {
 	puts stderr "Release3Canvas"
     }
 
     set ds9(b3) 0
-    ColorbarRelease3 $x $y
+    if {$current(frame) != {}} {
+	ColorbarRelease3 $current(frame) $x $y
+    }
 }
 
 proc UnBindEventsCanvas {} {
     global ds9
 
-    foreach f $ds9(active) {
-	UnBindEventsFrame $f
+    foreach ff $ds9(active) {
+	UnBindEventsFrame $ff
+	UnBindEventsColorbar ${ff}cb
+	UnBindEventsGraph $ff
     }
 }
 
 proc BindEventsCanvas {} {
     global ds9
-    global current
 
-    switch -- $ds9(display) {
-	single -
-	blink {BindEventsFrame $current(frame)}
-	tile {
-	    foreach f $ds9(active) {
-		BindEventsFrame $f
-	    }
-	}
+    foreach ff $ds9(active) {
+	BindEventsFrame $ff
+	BindEventsColorbar ${ff}cb
+	BindEventsGraph $ff
     }
 }
 
-# view
-
-proc ConfigureView {} {
-    global ds9
-    global canvas
-
-    global debug
-    if {$debug(tcl,layout)} {
-	puts stderr "ConfigureView old $canvas(width) $canvas(height)"
-    }
-
-    # calculate ds9(canvas) size
-    LayoutViewAdjust diff
-
-    # adjust window size
-    set canvas(width) [expr [winfo width $ds9(canvas)]-$diff(x)]
-    set canvas(height) [expr [winfo height $ds9(canvas)]-$diff(y)]
-
-    if {$debug(tcl,layout)} {
-	puts stderr "ConfigureView new $canvas(width) $canvas(height)"
-    }
-
-    LayoutView
-}
-
-proc UpdateView {} {
-    global ds9
-    global canvas
-
-    # note: assume canvas(width) and canvas(height) have been set to desired
-    # values.
-
-    global debug
-    if {$debug(tcl,layout)} {
-	puts stderr "UpdateView to $canvas(width) x $canvas(height)"
-    }
-
-    # save current size
-    set wo [winfo width $ds9(top)]
-    set ho [winfo height $ds9(top)]
-
-    # calculate ds9(canvas) size
-    LayoutViewAdjust diff
-
-    # adjust window size
-    set ww [expr $canvas(width)+$diff(x)]
-    set hh [expr $canvas(height)+$diff(y)]
-
-    # determine how much to change
-    set wc [winfo width $ds9(canvas)]
-    set hc [winfo height $ds9(canvas)]
-
-    set wt [winfo width $ds9(top)]
-    set ht [winfo height $ds9(top)]
-    
-    if {$debug(tcl,layout)} {
-	puts stderr "UpdateView before ds9(top) $wt x $ht"
-    }
-
-    set w [expr $ww - $wc + $wt]
-    set h [expr $hh - $hc + $ht]
-
-    if {$debug(tcl,layout)} {
-	puts stderr "UpdateView after ds9(top) $w x $h"
-    }
-
-    # change window size
-    wm geometry $ds9(top) ${w}x${h}
-
-    LayoutView
-}
-
 proc LayoutView {} {
     global view
 
@@ -368,134 +294,6 @@ proc LayoutView {} {
     LayoutInfoPanel
     LayoutButtons
     LayoutFrames
-    LayoutColorbar
-
-    UpdateGraphLayout {}
-}
-
-proc LayoutViewAdjust {varname} {
-    upvar $varname var
-
-    global debug
-    if {$debug(tcl,layout)} {
-	puts stderr "LayoutViewAdjust"
-    }
-
-    global view
-    global colorbar
-    global icolorbar
-    global igraph
-    global canvas
-    global ds9
-
-    set var(x) 0
-    set var(y) 0
-
-    set cbh [expr $view(colorbar) && \
-	     [string equal $colorbar(orientation) {horizontal}]]
-    set cbv [expr $view(colorbar) && \
-	     [string equal $colorbar(orientation) {vertical}]]
-    set grh $view(graph,horz)
-    set grv $view(graph,vert)
-
-    if {$colorbar(numerics)} {
-	# ww horizontal: tickgap
-	set ww 12
-	# hh vertical: approx number of numerals to display
-	set hh 7
-
-	set icolorbar(horizontal,height) \
-	    [expr int($colorbar(size) + $colorbar(font,size)*$ds9(scaling)+$ww)]
-
-	set icolorbar(vertical,width) \
-	    [expr $colorbar(size) + $colorbar(font,size)*$hh]
-    } else {
- 	set icolorbar(horizontal,height) [expr $colorbar(size) +2]
- 	set icolorbar(vertical,width) [expr $colorbar(size) +2]
-    }
-
-    # basics
-    if {$cbh} {
-	incr var(y) $icolorbar(horizontal,height)
-    }
-
-    if {$cbv} {
-	incr var(x) $icolorbar(vertical,width)
-    }
-
-    if {$grh} {
-	incr var(y)  $igraph(size)
-    }
-
-    if {$grv} {
-	incr var(x)  $igraph(size)
-    }
-
-    # canvas gap
-    if {$cbh || $grh} {
-	incr var(y) $canvas(gap)
-    }
-
-    if {$cbv || $grv} {
-	incr var(x) $canvas(gap)
-    }
-
-    # graph gap
-    if {$grv && !$cbh} {
-	incr var(y) $igraph(gap,y)
-    }
-
-    if {$grh && !$cbv} {
-	incr var(x) $igraph(gap,x)
-    }
-
-    global debug
-    if {$debug(tcl,layout)} {
-	puts stderr "LayoutViewAdjust $var(x) $var(y)"
-    }
-}
-
-proc LayoutOrient {} {
-    global ds9
-    global canvas
-
-    global debug
-    if {$debug(tcl,layout)} {
-	puts stderr "LayoutOrient"
-    }
-
-    # save original canvas size
-    set ww $canvas(width)
-    set hh $canvas(height)
-
-    # horizontal
-    grid rowconfigure $ds9(main) 4 -weight 0
-    grid columnconfigure $ds9(main) 0 -weight 0
-
-    # vertical
-    grid rowconfigure $ds9(main) 0 -weight 0
-    grid columnconfigure $ds9(main) 4 -weight 0
-
-    grid forget $ds9(panel)
-    grid forget $ds9(panel,sep)
-    grid forget $ds9(buttons)
-    grid forget $ds9(buttons,sep)
-    grid forget $ds9(image)
-    pack forget $ds9(info)
-    pack forget $ds9(panner)
-    pack forget $ds9(magnifier)
-
-    UpdateView
-    global debug
-    if {$debug(tcl,idletasks)} {
-	puts stderr "LayoutOrient update"
-    }
-    update
-
-    # restore original canvas size
-    set canvas(width) $ww
-    set canvas(height) $hh
-    UpdateView
 }
 
 proc LayoutViewHorz {} {
@@ -503,32 +301,36 @@ proc LayoutViewHorz {} {
     global current
     global view
 
-    # canvas
+    # ds9(main) weight
     grid rowconfigure $ds9(main) 4 -weight 1
     grid columnconfigure $ds9(main) 0 -weight 1
-    grid $ds9(image) -row 4 -column 0 -sticky news
+    grid rowconfigure $ds9(main) 0 -weight 0
+    grid columnconfigure $ds9(main) 4 -weight 0
+
+    grid forget $ds9(panel)
+    grid forget $ds9(panel,sep)
+    grid forget $ds9(buttons,frame)
+    grid forget $ds9(buttons,sep)
+    grid forget $ds9(image)
+
+    pack forget $ds9(info)
+    pack forget $ds9(magnifier)
+    pack forget $ds9(panner)
 
     # info panel
     if {$view(info) || $view(magnifier) || $view(panner)} {
 	grid $ds9(panel) -row 0 -column 0 -sticky ew -columnspan 3
 	$ds9(panel,sep) configure -orient horizontal
 	grid $ds9(panel,sep) -row 1 -column 0 -sticky ew -columnspan 3
-    } else {
-	grid forget $ds9(panel)
-	grid forget $ds9(panel,sep)
     }
 
     if {$view(info)} {
 	pack $ds9(info) -side left -anchor nw -padx 2 -pady 2 \
 	    -fill x -expand true
-    } else {
-	pack forget $ds9(info)
     }
 
     if {$view(panner)} {
 	pack $ds9(panner) -side right -padx 2 -pady 2
-    } else {
-	pack forget $ds9(panner)
     }
 
     if {$view(magnifier)} {
@@ -536,19 +338,17 @@ proc LayoutViewHorz {} {
 	if {$view(panner)} {
 	    pack $ds9(magnifier) -before $ds9(panner)
 	}
-    } else {
-	pack forget $ds9(magnifier)
     }
 
     # buttons
     if {$view(buttons)} {
-	grid $ds9(buttons) -row 2 -sticky ew -columnspan 3
+	grid $ds9(buttons,frame) -row 2 -sticky ew -columnspan 3
 	$ds9(buttons,sep) configure -orient horizontal
 	grid $ds9(buttons,sep) -row 3 -column 0 -sticky ew -columnspan 3
-    } else {
-	grid forget $ds9(buttons)
-	grid forget $ds9(buttons,sep)
     }
+
+    # image
+    grid $ds9(image) -row 4 -column 0 -sticky news
 }
 
 proc LayoutViewVert {} {
@@ -556,25 +356,31 @@ proc LayoutViewVert {} {
     global current
     global view
 
-    # canvas
+    # ds9(main) weight
+    grid rowconfigure $ds9(main) 4 -weight 0
+    grid columnconfigure $ds9(main) 0 -weight 0
     grid rowconfigure $ds9(main) 0 -weight 1
     grid columnconfigure $ds9(main) 4 -weight 1
-    grid $ds9(image) -row 0 -column 4 -sticky news
+
+    grid forget $ds9(panel)
+    grid forget $ds9(panel,sep)
+    grid forget $ds9(buttons,frame)
+    grid forget $ds9(buttons,sep)
+    grid forget $ds9(image)
+    
+    pack forget $ds9(magnifier)
+    pack forget $ds9(info)
+    pack forget $ds9(panner)
 
     # info panel
     if {$view(info) || $view(magnifier) || $view(panner)} {
 	grid $ds9(panel) -row 0 -column 0 -sticky ns
 	$ds9(panel,sep) configure -orient vertical
 	grid $ds9(panel,sep) -row 0 -column 1 -sticky ns
-    } else {
-	grid forget $ds9(panel)
-	grid forget $ds9(panel,sep)
     }
 
     if {$view(magnifier)} {
 	pack $ds9(magnifier) -side top -padx 2 -pady 2
-    } else {
-	pack forget $ds9(magnifier)
     }
 
     if {$view(info)} {
@@ -582,25 +388,21 @@ proc LayoutViewVert {} {
 	if {$view(magnifier)} {
 	    pack $ds9(info) -after $ds9(magnifier)
 	}
-    } else {
-	pack forget $ds9(info)
     }
 
     if {$view(panner)} {
 	pack $ds9(panner) -side bottom -padx 2 -pady 2
-    } else {
-	pack forget $ds9(panner)
     }
 
     # buttons
     if {$view(buttons)} {
-	grid $ds9(buttons) -row 0 -column 2 -sticky ns
+	grid $ds9(buttons,frame) -row 0 -column 2 -sticky ns
 	$ds9(buttons,sep) configure -orient vertical
 	grid $ds9(buttons,sep) -row 0 -column 3 -sticky ns
-    } else {
-	grid forget $ds9(buttons)
-	grid forget $ds9(buttons,sep)
     }
+
+    # image
+    grid $ds9(image) -row 0 -column 4 -sticky news
 }
 
 proc LayoutFrames {} {
@@ -610,111 +412,247 @@ proc LayoutFrames {} {
     global view
     global colorbar
     
-    # turn everything off
-    foreach f $ds9(frames) {
-	$f hide
-	$f highlite off
-	$f panner off
-	$f magnifier off
-	UnBindEventsFrame $f
+    # turn off default colorbar
+    colorbar hide
+
+    # turn off default graphs
+    GraphHide graph horz
+    GraphHide graph vert
+
+    # all frames turn everything off
+    foreach ff $ds9(frames) {
+	$ff hide
+	$ff highlite off
+	$ff panner off
+	$ff magnifier off
+
+	# colorbar
+	${ff}cb hide
+
+	# graphs
+	GraphHide $ff horz
+	GraphHide $ff vert
     }
 
-    if {$ds9(active,num) > 0} {
-	switch -- $ds9(display) {
-	    single {TileOne}
-	    tile {
-		switch -- $tile(mode) {
-		    row {TileRect 1 $ds9(active,num) $tile(grid,gap)}
-		    column {TileRect $ds9(active,num) 1 $tile(grid,gap)}
-		    grid {
-			switch -- $tile(grid,mode) {
-			    automatic {
-				TileRect [expr int(sqrt($ds9(active,num)-1))+1] \
-				    [expr int(sqrt($ds9(active,num))+.5)] \
-				    $tile(grid,gap)
-			    }
-			    manual {
-				TileRect \
-				    $tile(grid,col) \
-				    $tile(grid,row) \
-				    $tile(grid,gap)
-			    }
-			}
-		    }
+    # be sure colorbar/graph sizes are correct
+    LayoutColorbarAdjust
+    LayoutGraphsAdjust
+
+    if {[llength $ds9(active)] > 0} {
+	LayoutFramesOneOrMore
+    } else {
+	LayoutFramesNone
+    }
+
+    # after all layed out, update data cut for graphs if needed
+    #  one problem- if single mode, non-current graphs are incorrectly updated
+    switch -- $current(mode) {
+	crosshair {
+	    if {$view(graph,horz) || $view(graph,vert)} {
+		update idletasks
+		foreach ff $ds9(active) {
+		    set vv [$ff get crosshair canvas]
+		    UpdateGraphsData $ff [lindex $vv 0] [lindex $vv 1] canvas
 		}
 	    }
-	    blink {TileOne}
 	}
-    } else {
-	set current(frame) {}
-	set ds9(next) {}
-
-	# panner
-	if {$view(panner)} {
-	    panner clear
-	}
-
-	# magnifier
-	if {$view(magnifier)} {
-	    magnifier clear
-	}
-
-	# process proper colorbar
-	colorbar show
-	colorbarrgb hide
-	$ds9(canvas) raise colorbar colorbarrgb
-
-	set current(colorbar) colorbar
-	set colorbar(map) [colorbar get name]
-	set colorbar(invert) [colorbar get invert]
-
-	# update menus/dialogs
-	UpdateDS9
     }
 }
 
+proc LayoutFramesNone {} {
+    global ds9
+    global current
+    global colorbar
+    global view
+    
+    set current(frame) {}
+    set current(colorbar) colorbar
 
-# This procedure is called when we have only 1 frames to display
+    set colorbar(map) [colorbar get name]
+    set colorbar(invert) [colorbar get invert]
 
-proc TileOne {} {
+    # panner
+    if {$view(panner)} {
+	panner clear
+    }
+
+    # magnifier
+    if {$view(magnifier)} {
+	magnifier clear
+    }
+
+    # colorbar
+    if {$view(colorbar)} {
+	if {[LayoutColorbar colorbar 0 0 [winfo width $ds9(canvas)] [winfo height $ds9(canvas)]]} {
+	    colorbar show
+	    $ds9(canvas) raise colorbar
+	}
+    }
+    
+    # graphs
+    if {$view(graph,horz)} {
+	LayoutGraphHorz graph 0 0 \
+	    [winfo width $ds9(canvas)] [winfo height $ds9(canvas)]
+	GraphShow graph horz
+    }
+    if {$view(graph,vert)} {
+	LayoutGraphVert graph 0 0 \
+	    [winfo width $ds9(canvas)] [winfo height $ds9(canvas)]
+	GraphShow graph vert
+    }
+
+    # update menus/dialogs
+    UpdateDS9
+}
+
+proc LayoutFramesOneOrMore {} {
+    global ds9
+    global view
+
+    switch -- $ds9(display) {
+	single {
+	    LayoutFrameOne
+	}
+	tile {
+	    if {[llength $ds9(active)] > 1} {
+		if {$view(multi)} {
+		    LayoutFrame
+		} else {
+		    LayoutFrameNone
+		}
+	    } else {
+		LayoutFrameOne
+	    }
+	}
+	blink {
+	    LayoutFrameOne
+	}
+    }
+}
+
+proc LayoutFrameOne {} {
     global ds9
     global view
     global current
-    global canvas
     global colorbar
 
-    set ww $canvas(width)
-    set hh $canvas(height)
-
-    set xx 0
-    set yy 0
+    set ww [winfo width $ds9(canvas)]
+    set hh [winfo height $ds9(canvas)]
 
     foreach ff $ds9(active) {
-	$ff configure -x $xx -y $yy -width $ww -height $hh -anchor nw
+	set fw $ww
+	set fh $hh
+
+	# frame
+	LayoutFrameAdjust fw fh
+	$ff configure -x 0 -y 0 -width $fw -height $fh -anchor nw
+
+	# colorbar
+	if {$view(colorbar)} {
+	    LayoutColorbar ${ff}cb 0 0 $ww $hh
+	}
+
+	# graphs
+	if {$view(graph,horz)} {
+	    LayoutGraphHorz $ff 0 0 $ww $hh
+	    UpdateGraphAxis $ff horz
+	}
+	if {$view(graph,vert)} {
+	    LayoutGraphVert $ff 0 0 $ww $hh
+	    UpdateGraphAxis $ff vert
+    	}
+    }
+
+    # frame
+    $current(frame) show
+    $ds9(canvas) raise $current(frame)
+
+    # colorbar
+    if {$view(colorbar)} {
+	$current(colorbar) show
+	$ds9(canvas) raise $current(colorbar)
+    }
+
+    # graphs
+    if {$view(graph,horz)} {
+	GraphShow $current(frame) horz
+    }
+    if {$view(graph,vert)} {
+	GraphShow $current(frame) vert
     }
 
-    # only show the current frame
     FrameToFront
 }
 
-proc TileRect {numx numy gap} {
-    global view
-    global canvas
+proc LayoutFrame {} {
+    global ds9
     global tile
 
-    set ww $canvas(width)
-    set hh $canvas(height)
+    set num [llength $ds9(active)]
+    switch -- $tile(mode) {
+	row {
+	    TileRect 1 $num
+	}
+	column {
+	    TileRect $num 1
+	}
+	grid {
+	    switch -- $tile(grid,mode) {
+		automatic {
+		    TileRect \
+			[expr int(sqrt($num-1))+1] [expr int(sqrt($num)+.5)]
+		}
+		manual {
+		    TileRect $tile(grid,col) $tile(grid,row)
+		}
+	    }
+	}
+    }
+}
+
+proc LayoutFrameNone {} {
+    global ds9
+    global tile
+
+    set num [llength $ds9(active)]
+    switch -- $tile(mode) {
+	row {
+	    TileRectNone 1 $num
+	}
+	column {
+	    TileRectNone $num 1
+	}
+	grid {
+	    switch -- $tile(grid,mode) {
+		automatic {
+		    TileRectNone \
+			[expr int(sqrt($num-1))+1] [expr int(sqrt($num)+.5)]
+		}
+		manual {
+		    TileRectNone $tile(grid,col) $tile(grid,row)
+		}
+	    }
+	}
+    }
+}
+
+proc TileRect {numx numy} {
+    global ds9
+    global tile
+    global current
+    global view
+    global colorbar
+
+    set ww [expr int(([winfo width  $ds9(canvas)]-($tile(grid,gap)*($numx-1)))/$numx)]
+    set hh [expr int(([winfo height $ds9(canvas)]-($tile(grid,gap)*($numy-1)))/$numy)]
 
-    set w [expr int(($ww-$gap*($numx-1))/$numx)]
-    set h [expr int(($hh-$gap*($numy-1))/$numy)]
-    
     switch $tile(grid,dir) {
 	x {
 	    for {set jj 0} {$jj<$numy} {incr jj} {
 		for {set ii 0} {$ii<$numx} {incr ii} {
 		    set nn [expr $jj*$numx + $ii]
-		    set x($nn) [expr ($w+$gap)*$ii]
-		    set y($nn) [expr ($h+$gap)*$jj]
+		    set xx($nn) [expr ($ww+$tile(grid,gap))*$ii]
+		    set yy($nn) [expr ($hh+$tile(grid,gap))*$jj]
 		}
 	    }
 	}
@@ -722,55 +660,283 @@ proc TileRect {numx numy gap} {
 	    for {set ii 0} {$ii<$numx} {incr ii} {
 		for {set jj 0} {$jj<$numy} {incr jj} {
 		    set nn [expr $ii*$numy + $jj]
-		    set x($nn) [expr ($w+$gap)*$ii]
-		    set y($nn) [expr ($h+$gap)*$jj]
+		    set xx($nn) [expr ($ww+$tile(grid,gap))*$ii]
+		    set yy($nn) [expr ($hh+$tile(grid,gap))*$jj]
 		}
 	    }
 	}
     }
 
-    TileIt $w $h x y [expr $numx*$numy]
-}
-
-proc TileIt {ww hh xvar yvar nn} {
-    upvar $xvar x
-    upvar $yvar y
-    global ds9
-    global current
-
     set ii 0
     foreach ff $ds9(active) {
-	if {$ii<$nn} {
-	    $ff configure -x $x($ii) -y $y($ii) \
-		-width $ww -height $hh -anchor nw
-	    $ff show
-	    $ds9(canvas) raise $ff
-	    if {!$ds9(freeze)} {
-		BindEventsFrame $ff
-	    }
+	set fw $ww
+	set fh $hh
+
+	# frame
+	LayoutFrameAdjust fw fh
+	$ff configure -x $xx($ii) -y $yy($ii) -width $fw -height $fh -anchor nw
+	$ff show
+	$ds9(canvas) raise $ff
+
+	# colorbar
+	if {$view(colorbar)} {
+	    LayoutColorbar ${ff}cb $xx($ii) $yy($ii) $ww $hh
+	    ${ff}cb show
+	    $ds9(canvas) raise ${ff}cb
 	}
+
+	# graphs
+	if {$view(graph,horz)} {
+	    LayoutGraphHorz $ff $xx($ii) $yy($ii) $ww $hh
+	    UpdateGraphAxis $ff horz
+	    GraphShow $ff horz
+	}
+	if {$view(graph,vert)} {
+	    LayoutGraphVert $ff $xx($ii) $yy($ii) $ww $hh
+	    UpdateGraphAxis $ff vert
+	    GraphShow $ff vert
+	}
+
 	incr ii
     }
 
-    # if manual grid, current frame could be not included
-    if {$current(frame) != {}} {
-	$current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
-    }
-    if {$ds9(active,num) > $nn} {
-	set current(frame) [lindex $ds9(active) 0]
-    }
     FrameToFront
 }
 
-proc DisplayDefaultDialog {} {
+proc TileRectNone {numx numy} {
+    global ds9
+    global tile
+    global current
+    global view
+    global colorbar
+    
+    set fw [winfo width $ds9(canvas)]
+    set fh [winfo height $ds9(canvas)]
+    LayoutFrameAdjust fw fh
+    
+    set ww [expr int(($fw-($tile(grid,gap)*($numx-1)))/$numx)]
+    set hh [expr int(($fh-($tile(grid,gap)*($numy-1)))/$numy)]
+
+    switch $tile(grid,dir) {
+	x {
+	    for {set jj 0} {$jj<$numy} {incr jj} {
+		for {set ii 0} {$ii<$numx} {incr ii} {
+		    set nn [expr $jj*$numx + $ii]
+		    set xx($nn) [expr ($ww+$tile(grid,gap))*$ii]
+		    set yy($nn) [expr ($hh+$tile(grid,gap))*$jj]
+		}
+	    }
+	}
+	y {
+	    for {set ii 0} {$ii<$numx} {incr ii} {
+		for {set jj 0} {$jj<$numy} {incr jj} {
+		    set nn [expr $ii*$numy + $jj]
+		    set xx($nn) [expr ($ww+$tile(grid,gap))*$ii]
+		    set yy($nn) [expr ($hh+$tile(grid,gap))*$jj]
+		}
+	    }
+	}
+    }
+
+    # frames
+    set ii 0
+    foreach ff $ds9(active) {
+	# sanity check
+	if {$xx($ii)>=0 && $yy($ii)>=0 && $ww>=0 && $hh>=0} {
+	    $ff configure -x $xx($ii) -y $yy($ii) \
+		-width $ww -height $hh -anchor nw
+	    $ff show
+	    $ds9(canvas) raise $ff
+	}
+
+	if {$view(colorbar)} {
+	    LayoutColorbar ${ff}cb 0 0 \
+		[winfo width $ds9(canvas)] [winfo height $ds9(canvas)]
+	}
+	
+	if {$view(graph,horz)} {
+	    LayoutGraphHorz $ff 0 0 \
+		[winfo width $ds9(canvas)] [winfo height $ds9(canvas)]
+	    UpdateGraphAxis $ff horz
+	}
+	
+	if {$view(graph,vert)} {
+	    LayoutGraphVert $ff 0 0 \
+		[winfo width $ds9(canvas)] [winfo height $ds9(canvas)]
+	    UpdateGraphAxis $ff vert
+	}
+
+	incr ii
+    }
+
+    # set colorbar/graph for current frame
+    set ff $current(frame)
+
+    # colorbar
+    if {$view(colorbar)} {
+	${ff}cb show
+	$ds9(canvas) raise ${ff}cb
+    }
+
+    # graphs
+    if {$view(graph,horz)} {
+	GraphShow $ff horz
+    }
+    if {$view(graph,vert)} {
+	GraphShow $ff vert
+    }
+
+    FrameToFront
+}
+
+proc LayoutFrameAdjust {wvar hvar} {
     global canvas
+    global view
+    global colorbar
+    global igraph
+    global dgraph
+    global graph
+
+    upvar $wvar ww
+    upvar $hvar hh
+
+    set cbh [expr $view(colorbar) && !$colorbar(orientation)]
+    set cbv [expr $view(colorbar) &&  $colorbar(orientation)]
+    set grh $view(graph,horz)
+    set grv $view(graph,vert)
+
+    # cbh
+    if {$cbh && !$cbv && !$grh && !$grv} {
+	incr hh -$colorbar(horizontal,height)
+	incr hh -$canvas(gap)
+    }
+    # cbv
+    if {!$cbh && $cbv && !$grh && !$grv} {
+	incr ww -$colorbar(vertical,width)
+	incr ww -$canvas(gap)
+    }
+
+    # cbhgrh
+    if {$cbh && !$cbv && $grh && !$grv} {
+	incr hh -$colorbar(horizontal,height)
+	incr hh -$canvas(gap)
+	incr hh -$graph(size)
+	incr ww -$dgraph(horz,offset)
+    }
+    # cbhgrv
+    if {$cbh && !$cbv && !$grh && $grv} {
+	incr hh -$colorbar(horizontal,height)
+	incr hh -$canvas(gap)
+	incr ww -$graph(size)
+    }
+    # cbhgrhgrv
+    if {$cbh && !$cbv && $grh && $grv} {
+	incr hh -$colorbar(horizontal,height)
+	incr hh -$canvas(gap)
+	incr hh -$graph(size)
+	incr ww -$graph(size)
+    }
+
+    # cbvgrh
+    if {!$cbh && $cbv && $grh && !$grv} {
+	incr ww -$colorbar(vertical,width)
+	incr ww -$canvas(gap)
+	incr hh -$graph(size)
+    }
+    # cbvgrv
+    if {!$cbh && $cbv && !$grh && $grv} {
+	incr ww -$colorbar(vertical,width)
+	incr ww -$canvas(gap)
+	incr ww -$graph(size)
+	incr hh -$dgraph(vert,offset)
+    }
+    # cbvgrhgrv
+    if {!$cbh && $cbv && $grh && $grv} {
+	incr ww -$colorbar(vertical,width)
+	incr ww -$canvas(gap)
+	incr ww -$graph(size)
+	incr hh -$graph(size)
+    }
+
+    # grh
+    if {!$cbh && !$cbv && $grh && !$grv} {
+	incr hh -$graph(size)
+	incr hh -$canvas(gap)
+	incr ww -$dgraph(horz,offset)
+    }
+    # grv
+    if {!$cbh && !$cbv && !$grh && $grv} {
+	incr ww -$graph(size)
+	incr ww -$canvas(gap)
+	incr hh -$dgraph(vert,offset)
+    }
+    # grhgrv
+    if {!$cbh && !$cbv && $grh && $grv} {
+	incr ww -$graph(size)
+	incr ww -$canvas(gap)
+	incr hh -$graph(size)
+	incr hh -$canvas(gap)
+    }
+
+    # sanity check
+    if {$ww<0} {
+	set ww 1
+    }
+    if {$hh<0} {
+	set hh 1
+    }
+}
+
+proc LayoutChangeWidth {ww} {
+    global ds9
+
+    set cw [winfo width $ds9(canvas)]
+    set tw [winfo width $ds9(top)]
+    set th [winfo height $ds9(top)]
+    set dw $ww-$cw
+
+    # change window size
+    wm geometry $ds9(top) "[expr $tw+$dw]x${th}"
+    LayoutView
+}
+
+proc LayoutChangeHeight {hh} {
+    global ds9
+    
+    set ch [winfo height $ds9(canvas)]
+    set tw [winfo width $ds9(top)]
+    set th [winfo height $ds9(top)]
+    set dh $hh-$ch
+
+    # change window size
+    wm geometry $ds9(top) "${tw}x[expr $th+$dh]"
+    LayoutView
+}
+
+proc LayoutChangeSize {ww hh} {
+    global ds9
+    
+    set cw [winfo width $ds9(canvas)]
+    set ch [winfo height $ds9(canvas)]
+    set tw [winfo width $ds9(top)]
+    set th [winfo height $ds9(top)]
+    set dw $ww-$cw
+    set dh $hh-$ch
+
+    # change window size
+    wm geometry $ds9(top) "[expr $tw+$dw]x[expr $th+$dh]"
+    LayoutView
+}
+
+proc DisplayDefaultDialog {} {
     global ed
+    global ds9
 
     set w {.defdpy}
 
     set ed(ok) 0
-    set ed(x) $canvas(width)
-    set ed(y) $canvas(height)
+    set ed(x) [winfo width $ds9(canvas)]
+    set ed(y) [winfo height $ds9(canvas)]
 
     DialogCreate $w [msgcat::mc {Display Size}] ed(ok)
 
@@ -806,9 +972,7 @@ proc DisplayDefaultDialog {} {
     destroy $w
 
     if {$ed(ok)} {
-	set canvas(width) $ed(x)
-	set canvas(height) $ed(y)
-	UpdateView
+	LayoutChangeSize $ed(x) $ed(y)
     }
 
     set rr $ed(ok)
@@ -816,24 +980,6 @@ proc DisplayDefaultDialog {} {
     return $rr
 }
 
-proc ViewHorzCmd {} {
-    global canvas
-    global icanvas
-
-    set canvas(width) $icanvas(horz,width)
-    set canvas(height) $icanvas(horz,height)
-    LayoutOrient
-}
-
-proc ViewVertCmd {} {
-    global canvas
-    global icanvas
-
-    set canvas(width) $icanvas(vert,width)
-    set canvas(height) $icanvas(vert,height)
-    LayoutOrient
-}
-
 # Process Cmds
 
 proc ProcessHeightCmd {varname iname} {
@@ -851,8 +997,8 @@ proc ProcessHeightCmd {varname iname} {
 }
 
 proc ProcessSendHeightCmd {proc id param {sock {}} {fn {}}} {
-    global canvas
-    $proc $id "$canvas(height)\n"
+    global ds9
+    $proc $id "[winfo height $ds9(canvas)]\n"
 }
 
 proc ProcessWidthCmd {varname iname} {
@@ -870,8 +1016,8 @@ proc ProcessWidthCmd {varname iname} {
 }
 
 proc ProcessSendWidthCmd {proc id param {sock {}} {fn {}}} {
-    global canvas
-    $proc $id "$canvas(width)\n"
+    global ds9
+    $proc $id "[winfo width $ds9(canvas)]\n"
 }
 
 proc ProcessViewCmd {varname iname} {
@@ -894,3 +1040,58 @@ proc ProcessSendViewCmd {proc id param {sock {}} {fn {}}} {
     viewsend::yyparse
 }
 
+if {0} {
+    # cbhcbvgrhgrv
+    if {$cbh && $cbv && $grh && $grv} {
+	# not possible
+    }
+    # cbhcbvgrh
+    if {$cbh && $cbv && $grh && !$grv} {
+	# not possible
+    }
+    # cbhcbvgrv
+    if {$cbh && $cbv && !$grh && $grv} {
+	# not possible
+    }
+    # cbhcbv
+    if {$cbh && $cbv && !$grh && !$grv} {
+	# not possible
+    }
+    # cbhgrhgrv
+    if {$cbh && !$cbv && $grh && $grv} {
+    }
+    # cbhgrh
+    if {$cbh && !$cbv && $grh && !$grv} {
+    }
+    # cbhgrv
+    if {$cbh && !$cbv && !$grh && $grv} {
+    }
+    # cbh
+    if {$cbh && !$cbv && !$grh && !$grv} {
+    }
+
+    # cbvgrhgrv
+    if {!$cbh && $cbv && $grh && $grv} {
+    }
+    # cbvgrh
+    if {!$cbh && $cbv && $grh && !$grv} {
+    }
+    # cbvgrv
+    if {!$cbh && $cbv && !$grh && $grv} {
+    }
+    # cbv
+    if {!$cbh && $cbv && !$grh && !$grv} {
+    }
+    # grhgrv
+    if {!$cbh && !$cbv && $grh && $grv} {
+    }
+    # grh
+    if {!$cbh && !$cbv && $grh && !$grv} {
+    }
+    # grv
+    if {!$cbh && !$cbv && !$grh && $grv} {
+    }
+    # 
+    if {!$cbh && !$cbv && !$grh && !$grv} {
+    }
+}
