@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -6,6 +6,7 @@ package provide DS9 1.0
 
 proc AnalysisMainMenu {} {
     global ds9
+    global graph
 
     # WARNING: this is a variable length menu. 
     # Be sure to update ds9(menu,size,analysis)
@@ -17,11 +18,14 @@ proc AnalysisMainMenu {} {
     $ds9(mb).analysis add separator
     $ds9(mb).analysis add command -label "[msgcat::mc {Mask Parameters}]..." \
 	-command MaskDialog
-    $ds9(mb).analysis add command -label "[msgcat::mc {Graph Parameters}]..." \
-	-command GraphDialog
     $ds9(mb).analysis add command \
 	-label "[msgcat::mc {Crosshair Parameters}]..." -command CrosshairDialog
     $ds9(mb).analysis add separator
+    $ds9(mb).analysis add cascade -label [msgcat::mc {Graph}] \
+	-menu $ds9(mb).analysis.graph
+    $ds9(mb).analysis add command -label "[msgcat::mc {Graph Parameters}]..." \
+	-command GraphDialog
+    $ds9(mb).analysis add separator
     $ds9(mb).analysis add checkbutton -label [msgcat::mc {Contours}] \
 	-variable contour(view) -command UpdateContour
     $ds9(mb).analysis add command -label "[msgcat::mc {Contour Parameters}]..."\
@@ -74,6 +78,36 @@ proc AnalysisMainMenu {} {
 	-label [msgcat::mc {Clear Analysis Commands}] \
 	-command ClearAnalysisMenu
 
+    ThemeMenu $ds9(mb).analysis.graph
+    $ds9(mb).analysis.graph add checkbutton -label [msgcat::mc {Grid}] \
+	-variable graph(grid) -command UpdateGraphsGrid
+    $ds9(mb).analysis.graph add separator
+    $ds9(mb).analysis.graph add cascade -label [msgcat::mc {Axis}] \
+	-menu $ds9(mb).analysis.graph.axis
+    $ds9(mb).analysis.graph add cascade -label [msgcat::mc {Method}] \
+	-menu $ds9(mb).analysis.graph.method
+    $ds9(mb).analysis.graph add cascade -label [msgcat::mc {Font}] \
+	-menu $ds9(mb).analysis.graph.font
+
+    ThemeMenu $ds9(mb).analysis.graph.axis
+    $ds9(mb).analysis.graph.axis add radiobutton \
+	-label [msgcat::mc {Linear}] -variable graph(log) \
+	-value 0 -command UpdateGraphsGrid
+    $ds9(mb).analysis.graph.axis add radiobutton \
+	-label [msgcat::mc {Log}] -variable graph(log) \
+	-value 1 -command UpdateGraphsGrid
+
+    ThemeMenu $ds9(mb).analysis.graph.method
+    $ds9(mb).analysis.graph.method add radiobutton \
+	-label [msgcat::mc {Average}] -variable graph(method) \
+	-value average -command UpdateGraphsMethod
+    $ds9(mb).analysis.graph.method add radiobutton \
+	-label [msgcat::mc {Sum}] -variable graph(method) \
+	-value sum -command UpdateGraphsMethod
+
+    FontMenu $ds9(mb).analysis.graph.font \
+	graph font font,size font,weight font,slant UpdateGraphsFont
+
     ThemeMenu $ds9(mb).analysis.block
     $ds9(mb).analysis.block add command -label [msgcat::mc {Block In}] \
 	-command {Block .5 .5}
@@ -162,8 +196,6 @@ proc AnalysisMainMenu {} {
 	-command PlotLineTool
     $ds9(mb).analysis.plot add command -label [msgcat::mc {Bar}] \
 	-command PlotBarTool
-    $ds9(mb).analysis.plot add command -label [msgcat::mc {Scatter}] \
-	-command PlotScatterTool
 }
 
 proc PrefsDialogAnalysisMenu {w} {
@@ -345,7 +377,7 @@ proc UpdateAnalysisMenu {} {
 	puts stderr "UpdateAnalysisMenu"
     }
 
-    if {$ds9(active,num) > 0} {
+    if {[llength $ds9(active)] > 0} {
 	$ds9(mb) entryconfig [msgcat::mc {Analysis}] -state normal
 	ConfigureButtons analysis normal
     } else {
@@ -377,6 +409,39 @@ proc UpdateAnalysisMenu {} {
     }
 }
 
+proc UpdateAnalysisButtonbar {} {
+    global ds9
+    global current
+    global ianalysis
+
+    global debug
+    if {$debug(tcl,update)} {
+	puts stderr "UpdateAnalysisButtonbar"
+    }
+
+    if {$current(frame) != {}} {
+	for {set ii 0} {$ii<$ianalysis(buttonbar,count)} {incr ii} {
+	    if {[$current(frame) has fits]} {
+		set fn [$current(frame) get fits file name 1]
+	    } else {
+		set fn {none}
+	    }
+
+	    for {set jj 0} {$jj<$ianalysis(buttonbar,$ii,count)} {incr jj} {
+		# disable by default
+		$ianalysis(buttonbar,$ii-$jj,button) configure -state disabled
+
+		foreach tt $ianalysis(buttonbar,$ii-$jj,template) {
+		    if {[regexp ".$tt" $fn]} {
+			$ianalysis(buttonbar,$ii-$jj,button) configure -state normal
+			break
+		    }
+		}
+	    }
+	}
+    }
+}
+
 proc PrefsDialogAnalysis {} {
     global dprefs
 
