@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -111,7 +111,7 @@ proc MarkerBaseColor {varname} {
     upvar #0 $varname var
     global $varname
 
-    $var(frame) marker $var(id) color $var(color)
+    $var(frame) marker $var(id) color "{$var(color)}"
 }
 
 proc MarkerBaseLineWidth {varname} {
