@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -116,7 +116,16 @@ proc ThemeConfigTable {w} {
 proc ThemeConfigPlot {w} {
     set varname [lindex [split $w {.}] 1]
     if {$varname != {}} {
-	PlotUpdateAllElement $varname
+	# All non-plot blt::graphs need to be listed here
+	#   scale
+	#   horz/vert graph
+	switch $varname {
+	    scale -
+	    ds9 {}
+	    default {
+		PlotUpdateAllElement $varname
+	    }
+	}
     }
 }
 
