@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -141,11 +141,11 @@ proc EnterPanner {x y} {
     }
 
     switch $ds9(wm) {
-	x11 -
-	aqua {
+	x11 {
 	    focus $ds9(panner)
 	    $ds9(panner) focus panner
 	}
+	aqua -
 	win32 {}
     }
 
@@ -166,17 +166,16 @@ proc LeavePanner {} {
 
     panner highlite off
     switch $ds9(wm) {
-	x11 -
-	aqua {
+	x11 {
 	    $ds9(panner) focus {}
 	    focus {}
 	}
+	aqua -
 	win32 {}
     }
 
     LeaveInfoBox
     PixelTableClearDialog
-    ClearGraphData
 }
 
 proc MotionPanner {x y} {
