@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -190,7 +190,7 @@ proc PreservePan {} {
 
 proc UpdatePan {which} {
     LockFrame $which
-    UpdateGraphAxis $which
+    UpdateGraphsAxis $which
     UpdatePanZoomDialog
     SAMPSendCoordPointAtSkyCmd $which
 }
@@ -271,7 +271,7 @@ proc ZoomShift {which} {
 
 proc UpdateZoom {which} {
     LockFrame $which
-    UpdateGraphAxis $which
+    UpdateGraphsAxis $which
     UpdatePanZoomDialog
     GridUpdateZoom
     RefreshInfoBox $which
@@ -340,7 +340,7 @@ proc RotateRelease {which x y} {
 
 proc UpdateRotate {which} {
     LockFrame $which
-    UpdateGraphAxis $which
+    UpdateGraphsAxis $which
     UpdatePanZoomDialog
     RefreshInfoBox $which
 }
@@ -498,7 +498,7 @@ proc PanZoomApplyDialog {} {
 	$current(frame) rotate to $current(rotate)
 
 	LockFrameCurrent
-	UpdateGraphAxis $current(frame)
+	UpdateGraphsAxis $current(frame)
 	UpdatePanZoomDialog
 	GridUpdateZoom
 	RefreshInfoBox $current(frame)
@@ -580,7 +580,7 @@ proc AlignWCSFrame {} {
 	$current(frame) wcs align $current(align)
 
 	LockFrameCurrent
-	UpdateGraphAxis $current(frame)
+	UpdateGraphsAxis $current(frame)
     }
 }
 
