@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -8,12 +8,12 @@ proc PlotDef {} {
     global iap
 
     set iap(tt) {ap}
-    set iap(windows) {}
-    set iap(unique) 0
+    set iap(plots) {}
+    set iap(tools) {}
+    set iap(unique) 1
 
     set iap(jpeg,quality) 75
     set iap(tiff,compress) none
-    set iap(error) [msgcat::mc {An error has occurred while creating the image. Please be sure that the plot window is in the upper left corner of the default screen and the entire window is visible.}]
 
     PlotDefState
 }
@@ -42,6 +42,11 @@ proc PlotDestroy {varname} {
     destroy $var(top)
     destroy $var(mb)
 
+    # gui window?
+    if {[winfo exists $var(gui,top)]} {
+	PlotGUIDestroy $varname
+    }
+
     # stats window?
     if {$var(stats)} {
 	SimpleTextDestroy "${varname}stats"
@@ -52,10 +57,10 @@ proc PlotDestroy {varname} {
 	SimpleTextDestroy "${varname}list"
     }
 
-    # delete it from the xpa list
-    set ii [lsearch $iap(windows) $varname]
+    # delete it from the list
+    set ii [lsearch $iap(plots) $varname]
     if {$ii>=0} {
-	set iap(windows) [lreplace $iap(windows) $ii $ii]
+	set iap(plots) [lreplace $iap(plots) $ii $ii]
     }
 
     unset $varname
@@ -74,6 +79,8 @@ proc PlotAddGraph {varname type} {
 
     # Init graph vars
     PlotInitGraph $varname
+    set var(graph) $var(top).gr$var(graph,current)
+    set var(graph,name) "Graph $var(seq)"
 
     # create graph
     set var(graph,type) $type
@@ -91,6 +98,7 @@ proc PlotAddGraph {varname type} {
 	    set var(graph,proc,button) PlotButton
 	}
 	scatter {
+	    # backward compatibility
 	    PlotScatterAddGraph $varname
 	    set var(graph,proc,updateelement) PlotScatterUpdateElement
 	    set var(graph,proc,highlite) PlotScatterHighliteElement
@@ -114,14 +122,14 @@ proc PlotAddGraph {varname type} {
     $var(graph,proc,updateelement) $varname
     PlotUpdateCanvas $varname
     PlotUpdateGraph $varname
-
     PlotUpdateMenus $varname
+    PlotUpdateGUI $varname
 
     PlotStats $varname
     PlotList $varname
 
+    PlotGUICurrentGraph $varname
     PlotChangeMode $varname
-
     PlotLayoutCanvas $varname
 }
 
@@ -183,8 +191,8 @@ proc PlotDeleteGraph {varname} {
     $var(graph,proc,updateelement) $varname
     PlotUpdateCanvas $varname
     PlotUpdateGraph $varname
-
     PlotUpdateMenus $varname
+    PlotUpdateGUI $varname
 
     PlotStats $varname
     PlotList $varname
@@ -202,6 +210,7 @@ proc PlotAddElement {varname} {
     # create graph elements
     set nn $var(graph,ds,current)
     global $var(graph,ds,xdata) $var(graph,ds,ydata)
+    
     $var(graph) element create $nn \
 	-xdata $var(graph,ds,xdata) -ydata $var(graph,ds,ydata) \
     
@@ -218,8 +227,8 @@ proc PlotAddElement {varname} {
 
     # update menus
     $var(graph,proc,updateelement) $varname
-
     PlotUpdateMenus $varname
+    PlotUpdateGUI $varname
 
     PlotStats $varname
     PlotList $varname
@@ -233,10 +242,6 @@ proc PlotDeleteDataSetCurrent {varname} {
 	return
     }
 
-    if {!$var(graph,ds,manage)} {
-	return
-    }
-
     PlotDeleteDataSet $varname
 }
 
@@ -296,8 +301,8 @@ proc PlotDeleteDataSet {varname} {
 
     # update menus
     $var(graph,proc,updateelement) $varname
-
     PlotUpdateMenus $varname
+    PlotUpdateGUI $varname
 
     PlotStats $varname
     PlotList $varname
@@ -313,11 +318,13 @@ proc PlotCurrentGraph {varname} {
     set var(graph,ds,current) [lindex $var($cc,dss) 0]
 
     PlotRestoreState $varname
-
     PlotUpdateMenus $varname
+    PlotUpdateGUI $varname
 
     PlotStats $varname
     PlotList $varname
+
+    PlotGUICurrentGraph $varname
 }
 
 # used by backup
@@ -335,7 +342,7 @@ proc PlotChangeAxis {varname} {
     upvar #0 $varname var
     global $varname
 
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	column -
 	row {PlotUpdateGraph $varname}
@@ -361,7 +368,7 @@ proc PlotChangeLegend {varname} {
     upvar #0 $varname var
     global $varname
 
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	column -
 	row {PlotUpdateGraph $varname}
@@ -391,6 +398,8 @@ proc PlotChangeLayout {varname} {
     set var(graph,ds,current) $nn
     PlotRestoreState $varname
     PlotUpdateMenus $varname
+    PlotUpdateGUI $varname
+
     PlotLayoutCanvas $varname
     PlotChangeMode $varname
 }
@@ -399,7 +408,7 @@ proc PlotChangeTitle {varname} {
     upvar #0 $varname var
     global $varname
 
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	column -
 	row {PlotUpdateGraph $varname}
@@ -407,6 +416,27 @@ proc PlotChangeTitle {varname} {
     }
 }
 
+proc PlotUpdateAllElement {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    set cc $var(graph,current)
+    set nn $var(graph,ds,current)
+    foreach gg $var(graphs) {
+	set var(graph,current) $gg
+	foreach hh $var($gg,dss) {
+	    set var(graph,ds,current) $hh
+	    PlotRestoreState $varname
+	    $var(graph,proc,updateelement) $varname
+	}
+    }
+    set var(graph,current) $cc
+    set var(graph,ds,current) $nn
+    PlotRestoreState $varname
+
+    PlotUpdateCanvasElement $varname
+}
+
 # used by backup
 proc PlotChangeMode {varname} {
     upvar #0 $varname var
@@ -423,7 +453,7 @@ proc PlotChangeMode {varname} {
 	    }
 	    zoom {
 		bind $var($cc,graph) <1> {}
-		switch $var(layout) {
+		switch $var(canvas,layout) {
 		    grid -
 		    row -
 		    column {
@@ -528,40 +558,6 @@ proc PlotPing {varname} {
     return 0
 }
 
-proc PlotBGColor {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global ds9
-    switch $ds9(wm) {
-	x11 -
-	win32 {return $var(background)}
-	aqua {
-	    switch $var(background) {
-		white {return $var(bg)}
-		default {return $var(background)}
-	    }
-	}
-    }
-}
-
-proc PlotFGColor {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global ds9
-    switch $ds9(wm) {
-	x11 -
-	win32 {return $var(foreground)}
-	aqua {
-	    switch $var(foreground) {
-		black {return $var(fg)}
-		default {return $var(foreground)}
-	    }
-	}
-    }
-}
-
 proc PlotRaise {varname} {
     upvar #0 $varname var
     global $varname
@@ -633,7 +629,7 @@ proc PlotLayoutCanvas {varname} {
 	place forget $var($cc,graph)
     }
 
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid {
 	    set ll [llength $var(graphs)]
 	    set nr [expr int(sqrt($ll)+.5)]
@@ -689,7 +685,7 @@ proc PlotLayoutCanvas {varname} {
 	    }
 	}
 	strip {
-	    set pp [expr $var(layout,strip,scale)/100.]
+	    set pp [expr $var(canvas,layout,strip,scale)/100.]
 	    if {$pp<0 && $pp>1} {
 		set pp 1
 	    }
@@ -725,6 +721,10 @@ proc PlotLayoutCanvas {varname} {
     PlotRestoreState $varname
 
     # needed so layout can be properly realized
+    global debug
+    if {$debug(tcl,idletasks)} {
+	puts stderr "PlotLayoutCanvas"
+    }
     update idletasks
 }
 
@@ -774,14 +774,14 @@ proc PlotCalcMargins {varname rpixname lpixname} {
 	}
     }
     if {$rchar>0} {
-	set rpix [expr $rpix + int(($var(legend,title,size)*4 + $var(legend,font,size)*$rchar)*.75)]
+	set rpix [expr $rpix + int(($var(canvas,legend,title,size)*4 + $var(canvas,legend,font,size)*$rchar)*.75)]
     }
     if {$lchar>0} {
-	set lpix [expr $lpix + int(($var(legend,title,size)*4 + $var(legend,font,size)*$lchar)*.75)]
+	set lpix [expr $lpix + int(($var(canvas,legend,title,size)*4 + $var(canvas,legend,font,size)*$lchar)*.75)]
     }
 
     set rpix [expr 10 + $rpix]
-    set lpix [expr 8*$var(axis,font,size) + $ytitle*$var(axis,title,size) + $lpix]
+    set lpix [expr 8*$var(canvas,axis,font,size) + $ytitle*$var(canvas,axis,title,size) + $lpix]
 }
 
 
@@ -797,7 +797,7 @@ proc PlotUpdateCanvas {varname} {
     set first [lindex $var(graphs) 0]
     set last [lindex $var(graphs) end]
     
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	row -
 	column {
@@ -833,7 +833,7 @@ proc PlotUpdateCanvas {varname} {
     
     set right 0
     set left 0
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	row -
 	column {}
@@ -843,42 +843,11 @@ proc PlotUpdateCanvas {varname} {
     }
     
     foreach cc $var(graphs) {
-	$var($cc,graph) configure -plotpadx 0 -plotpady 0 \
-	    -bg [PlotBGColor $varname] \
-	    -plotbackground [PlotBGColor $varname] \
-	    -fg [PlotFGColor $varname] \
-	    -font "{$ds9($var(graph,title,family))} $var(graph,title,size) $var(graph,title,weight) $var(graph,title,slant)"
-
-	$var($cc,graph) xaxis configure \
-	    -bg [PlotBGColor $varname] \
-	    -color [PlotFGColor $varname] \
-	    -titlecolor [PlotFGColor $varname] \
-	    -gridcolor $var(grid,color) \
-	    -gridminorcolor $var(grid,color) \
-	    -tickfont "{$ds9($var(axis,font,family))} $var(axis,font,size) $var(axis,font,weight) $var(axis,font,slant)" \
-	    -titlefont "{$ds9($var(axis,title,family))} $var(axis,title,size) $var(axis,title,weight) $var(axis,title,slant)"
-
-	$var($cc,graph) yaxis configure \
-	    -bg [PlotBGColor $varname] \
-	    -color [PlotFGColor $varname] \
-	    -titlecolor [PlotFGColor $varname] \
-	    -gridcolor $var(grid,color) \
-	    -gridminorcolor $var(grid,color) \
-	    -tickfont "{$ds9($var(axis,font,family))} $var(axis,font,size) $var(axis,font,weight) $var(axis,font,slant)" \
-	    -titlefont "{$ds9($var(axis,title,family))} $var(axis,title,size) $var(axis,title,weight) $var(axis,title,slant)"
-
-	$var($cc,graph) legend configure \
-	    -bg [PlotBGColor $varname] \
-	    -fg [PlotFGColor $varname] \
-	    -titlecolor [PlotFGColor $varname] \
-	    -font "{$ds9($var(legend,font,family))} $var(legend,font,size) $var(legend,font,weight) $var(legend,font,slant)" \
-	    -titlefont "{$ds9($var(legend,title,family))} $var(legend,title,size) $var(legend,title,weight) $var(legend,title,slant)"
-
-	switch $var(layout) {
+	switch $var(canvas,layout) {
 	    grid -
 	    row -
 	    column {
-		set var($cc,axis,x,manage) 1
+		set var($cc,layout,x,manage) 1
 		$var($cc,graph) configure \
 		    -topmargin 0 -bottommargin 0 \
 		    -leftmargin 0 -rightmargin 0 \
@@ -889,9 +858,9 @@ proc PlotUpdateCanvas {varname} {
 	    }
 	    strip {
 		if {$cc == $first} {
-		    set var($cc,axis,x,manage) 1
+		    set var($cc,layout,x,manage) 1
 		} else {
-		    set var($cc,axis,x,manage) 0
+		    set var($cc,layout,x,manage) 0
 		}
 
 		$var($cc,graph) configure \
@@ -916,6 +885,8 @@ proc PlotUpdateCanvas {varname} {
 	    }
 	}
     }
+
+    PlotUpdateCanvasElement $varname
 }
 
 proc PlotUpdateGraph {varname} {
@@ -924,7 +895,7 @@ proc PlotUpdateGraph {varname} {
 
     PlotSaveState $varname
 
-    if {$var(graph,axis,x,manage)} {
+    if {$var(graph,layout,x,manage)} {
 	if {$var(graph,axis,x,auto)} {
 	    set xmin {}
 	    set xmax {}
@@ -945,7 +916,7 @@ proc PlotUpdateGraph {varname} {
 	set ymax $var(graph,axis,y,max)
     }
 
-    if {$var(graph,axis,x,manage)} {
+    if {$var(graph,layout,x,manage)} {
 	set xtitle $var(graph,axis,x,title)
 	set xgrid $var(graph,axis,x,grid)
 	set xlog $var(graph,axis,x,log)
@@ -957,12 +928,6 @@ proc PlotUpdateGraph {varname} {
 	set xflip $var(layout,axis,x,flip)
     }
 
-    switch $var(graph,type) {
-	line {}
-	bar {$var(graph) configure -barmode $var(bar,mode)}
-	scatter {}
-    }
-
     if {$var(graph,format)} {
 	if {$var(graph,axis,x,format) != {}} {
 	    $var(graph) xaxis configure \
@@ -986,7 +951,7 @@ proc PlotUpdateGraph {varname} {
 	-min $ymin -max $ymax -descending $var(graph,axis,y,flip) \
 	-grid $var(graph,axis,y,grid) -logscale $var(graph,axis,y,log)
 
-    if {$var(graph,axis,x,manage)} {
+    if {$var(graph,layout,x,manage)} {
 	$var(graph) configure -plotpadx 0 -plotpady 0 -title $var(graph,title) 
     } else {
 	$var(graph) configure -plotpadx 0 -plotpady 0 -title {}
@@ -1000,7 +965,7 @@ proc PlotUpdateGraph {varname} {
 
     $var(graph) yaxis configure -title $var(graph,axis,y,title)
 
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	row -
 	column {
@@ -1011,7 +976,7 @@ proc PlotUpdateGraph {varname} {
 	strip {
 	    switch $var(graph,legend,position) {
 		top {
-		    if {$var(graph,axis,x,manage)} {
+		    if {$var(graph,layout,x,manage)} {
 			$var(graph) legend configure \
 			    -hide [expr !$var(graph,legend)] \
 			    -title $var(graph,legend,title) \
@@ -1063,32 +1028,6 @@ proc PlotHighliteElement {varname cc nn rowlist} {
 }
 
 # menus
-proc PlotColorMenu {w varname color cmd} {
-    upvar #0 $varname var
-    global $varname
-
-    menu $w
-    $w add radiobutton -label [msgcat::mc {Black}] \
-	-variable ${varname}($color) -value black -command $cmd
-    $w add radiobutton -label [msgcat::mc {White}] \
-	-variable ${varname}($color) -value white -command $cmd
-    $w add radiobutton -label [msgcat::mc {Red}] \
-	-variable ${varname}($color) -value red -command $cmd
-    $w add radiobutton -label [msgcat::mc {Green}] \
-	-variable ${varname}($color) -value green -command $cmd
-    $w add radiobutton -label [msgcat::mc {Blue}] \
-	-variable ${varname}($color) -value blue -command $cmd
-    $w add radiobutton -label [msgcat::mc {Cyan}] \
-	-variable ${varname}($color) -value cyan -command $cmd
-    $w add radiobutton -label [msgcat::mc {Magenta}] \
-	-variable ${varname}($color) -value magenta -command $cmd
-    $w add radiobutton -label [msgcat::mc {Yellow}] \
-	-variable ${varname}($color) -value yellow -command $cmd
-    $w add separator
-    $w add command -label "[msgcat::mc {Other Color}]..." \
-	-command [list ColorMenuOther $varname $color $cmd]
-}
-
 proc PlotTitle {varname title xaxis yaxis} {
     upvar #0 $varname var
     global $varname
@@ -1104,11 +1043,19 @@ proc PlotDataSetName {varname name} {
     upvar #0 $varname var
     global $varname
 
+    if {[llength $var(graph,dss)] == 0} {
+	return
+    }
+
+    if {$name == {}} {
+	set nn $var(graph,ds,current)
+	set name "Dataset $nn"
+    }
     $var(mb).graph.select entryconfig "$var(graph,ds,name)" -label "$name"
     set var(graph,ds,name) $name
     $var(graph,proc,updateelement) $varname
 
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	row -
 	column {}
@@ -1116,84 +1063,49 @@ proc PlotDataSetName {varname name} {
     }
 }
 
-proc PlotBackup {ch dir} {
-    global iap
+proc PlotUpdateCanvasElement {varname} {
+    upvar #0 $varname var
+    global $varname
+    global ds9
 
-    set rdir "./[lindex [file split $dir] end]"
+    if {$var(canvas,theme)} {
+	set fg [ThemeTreeForeground]
+	set bg [ThemeTreeBackground]
+    } else {
+	set fg $var(canvas,foreground)
+	set bg $var(canvas,background)
+    }
 
-    # only save ap plots
-    foreach ww $iap(windows) {
-	if {[string range $ww 0 1] == {ap}} {
-	    set fdir [file join $dir $ww]
-	    
-	    # create dir if needed
-	    if {![file isdirectory $fdir]} {
-		if {[catch {file mkdir $fdir}]} {
-		    Error [msgcat::mc {An error has occurred during backup}]
-		    return
-		}
-	    }
+    foreach cc $var(graphs) {
+	$var($cc,graph) configure -plotpadx 0 -plotpady 0 \
+	    -bg $bg \
+	    -plotbackground $bg \
+	    -fg $fg \
+	    -font "{$ds9($var(canvas,title,family))} $var(canvas,title,size) $var(canvas,title,weight) $var(canvas,title,slant)"
 
-	    set varname $ww
-	    upvar #0 $varname var
-	    global $varname
+	$var($cc,graph) xaxis configure \
+	    -bg $bg \
+	    -color $fg \
+	    -titlecolor $fg \
+	    -gridcolor $var(canvas,grid,color) \
+	    -gridminorcolor $var(canvas,grid,color) \
+	    -tickfont "{$ds9($var(canvas,axis,font,family))} $var(canvas,axis,font,size) $var(canvas,axis,font,weight) $var(canvas,axis,font,slant)" \
+	    -titlefont "{$ds9($var(canvas,axis,title,family))} $var(canvas,axis,title,size) $var(canvas,axis,title,weight) $var(canvas,axis,title,slant)"
 
-	    puts $ch "global $varname"
-	    puts $ch "PlotDialog $varname $varname"
+	$var($cc,graph) yaxis configure \
+	    -bg $bg \
+	    -color $fg \
+	    -titlecolor $fg \
+	    -gridcolor $var(canvas,grid,color) \
+	    -gridminorcolor $var(canvas,grid,color) \
+	    -tickfont "{$ds9($var(canvas,axis,font,family))} $var(canvas,axis,font,size) $var(canvas,axis,font,weight) $var(canvas,axis,font,slant)" \
+	    -titlefont "{$ds9($var(canvas,axis,title,family))} $var(canvas,axis,title,size) $var(canvas,axis,title,weight) $var(canvas,axis,title,slant)"
 
-	    set cc $var(graph,current)
-	    set gr $var(graph,current)
-	    set ds $var(graph,ds,current)
-
-	    foreach cc $var(graphs) {
-		set var(graph,current) $cc
-		PlotCurrentGraph $varname
-		puts $ch "PlotAddGraph $varname $var($cc,type)"
-
-		# in case of no data
-		PlotSaveConfigFile $varname "$fdir/graph${cc}.plt"
-		puts $ch "PlotLoadConfigFile $varname $fdir/graph${cc}.plt"
-
-		# for each dataset
-		foreach nn $var($cc,dss) {
-		    set var(graph,ds,current) $nn
-		    PlotCurrentDataSet $varname
-
-		    PlotSaveDataFile $varname "$fdir/graph${cc}ds${nn}.dat"
-		    puts $ch "PlotLoadDataFile $varname $fdir/graph${cc}ds${nn}.dat $var($cc,$nn,dim)"
-
-		    PlotSaveConfigFile $varname "$fdir/graph${cc}ds${nn}.plt"
-
-		    puts $ch "PlotLoadConfigFile $varname $fdir/graph${cc}ds${nn}.plt"
-		}
-	    }
-	    puts $ch "wm geometry $var(top) [winfo width $var(top)]x[winfo height $var(top)]"
-	    puts $ch "set ${varname}(layout) $var(layout)"
-	    puts $ch "set ${varname}(layout,strip,scale) $var(layout,strip,scale)"
-	    puts $ch "PlotChangeLayout $varname"
-
-	    puts $ch "set ${varname}(foreground) $var(foreground)"
-	    puts $ch "set ${varname}(background) $var(background)"
-	    puts $ch "set ${varname}(grid,color) $var(grid,color)"
-	    puts $ch "set ${varname}(bar,mode) $var(bar,mode)"
-	    puts $ch "PlotUpdateCanvas $varname"
-
-	    puts $ch "set ${varname}(mode) $var(mode)"
-	    puts $ch "PlotChangeMode $varname"
-
-	    puts $ch "set ${varname}(graph,current) $gr"
-	    puts $ch "PlotCurrentGraph $varname"
-
-	    puts $ch "set ${varname}(graph,ds,current) $ds"
-	    puts $ch "PlotCurrentDataSet $varname"
-
-	    set var(graph,current) $gr
-	    PlotCurrentGraph $varname
-	    
-	    set var(graph,ds,current) $ds
-	    PlotCurrentDataSet $varname
-	}
+	$var($cc,graph) legend configure \
+	    -bg $bg \
+	    -fg $fg \
+	    -titlecolor $fg \
+	    -font "{$ds9($var(canvas,legend,font,family))} $var(canvas,legend,font,size) $var(canvas,legend,font,weight) $var(canvas,legend,font,slant)" \
+	    -titlefont "{$ds9($var(canvas,legend,title,family))} $var(canvas,legend,title,size) $var(canvas,legend,title,weight) $var(canvas,legend,title,slant)"
     }
 }
-
-
