@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -156,8 +156,6 @@ proc PlotDialog {varname wtt {theme true}} {
 	-command [list PlotAddGraph $varname line]
     $var(mb).canvas.graph add command -label [msgcat::mc {Bar}] \
 	-command [list PlotAddGraph $varname bar]
-    $var(mb).canvas.graph add command -label [msgcat::mc {Scatter}] \
-	-command [list PlotAddGraph $varname scatter]
 
     ThemeMenu $var(mb).canvas.layout
     $var(mb).canvas.layout add radiobutton -label [msgcat::mc {Grid}] \
@@ -277,6 +275,7 @@ proc PlotDialog {varname wtt {theme true}} {
 
     PlotLineMenus $varname
     PlotBarMenus $varname
+    # backward compatibility
     PlotScatterMenus $varname
 
     # GUI
@@ -651,12 +650,11 @@ proc PlotExportPhoto {varname fn format} {
     global $varname
     global iap
 
-    # for darwin only
     set geom [MacOSPhotoFix $var(top) 0 0]
 
     set rr [catch {image create photo -format window -data $var(top)} ph]
     if {$rr} {
-	Error $iap(error)
+	Error [msgcat::mc {An error has occurred while creating}]
 	return
     }
 
@@ -672,7 +670,7 @@ proc PlotExportPhoto {varname fn format} {
     image delete $ph
 
     # reset if needed
-    DarwinPhotoRestore $var(top) $geom
+    MacOSPhotoRestore $var(top) $geom
 }
 
 proc PlotUpdateMenus {varname} {
@@ -759,6 +757,7 @@ proc PlotUpdateMenus {varname} {
 		-menu $var(mb).databar
 	}
 	scatter {
+	    # backward compatibility
 	    $var(mb) add cascade -label [msgcat::mc {Data}] \
 		-menu $var(mb).datascatter
 	}
