@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -11,7 +11,6 @@ proc PrefsDef {} {
 
     set iprefs(top) .pf
     set iprefs(mb) .pfmb
-    set iprefs(tabs) {}
 
     set prefs(ext) {.prf}
     set prefs(version) [lindex $ds9(version) 0]
@@ -470,6 +469,8 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	6.0 {
 	    FixPrefs6.0to6.1 
@@ -483,6 +484,8 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	6.1 -
 	6.1.1 -
@@ -497,6 +500,8 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	6.2 {
 	    FixPrefs6.2to7.0
@@ -508,8 +513,11 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
-	7.0 {
+	7.0 -
+	7.0.1 {
 	    FixPrefs7.0to7.1
 	    FixPrefs7.1to7.2
 	    FixPrefs7.2to7.3
@@ -518,6 +526,8 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	7.1 {
 	    FixPrefs7.1to7.2
@@ -527,6 +537,8 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	7.2 {
 	    FixPrefs7.2to7.3
@@ -535,6 +547,8 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	7.3 -
 	7.3.1 -
@@ -544,27 +558,46 @@ proc FixPrefs {version} {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	7.4 {
 	    FixPrefs7.4to7.5
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	7.5 {
 	    FixPrefs7.5to7.6
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	7.6 {
 	    FixPrefs7.6to8.0
 	    FixPrefs8.0to8.1
-
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
 	}
 	8.0 {
 	    FixPrefs8.0to8.1
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
+	}
+	8.1 {
+	    FixPrefs8.1to8.2
+	    FixPrefs8.2to8.3
+	}
+	8.2 {
+	    FixPrefs8.2to8.3
+	}
+	8.3 {
+	    # beta fix
+	    FixPrefs8.3to8.3
 	}
-	8.1 {}
     }
 }
 
@@ -592,6 +625,115 @@ proc FixPrefsVarOld {} {
 
     # 8.0
     FixVarRm pbuttons(file,samp)
+
+    # 8.1
+    FixVarRm pbuttons(region,mask)
+
+    # 8.2
+    FixVar pbuttons(region,delete) pbuttons(region,deleteall)
+
+    # 8.3
+
+    # and fix any previous theme issues
+    global pds9
+    global ds9
+    switch $ds9(wm) {
+	x11 -
+	win32 {
+	    if {[info exists pds9(theme)]} {
+		if {[lsearch -nocase $ds9(themes) $pds9(theme)] == -1} {
+		    set pds9(theme) default
+		}
+	    }
+	}
+	aqua {}
+    }
+}
+
+proc FixPrefs8.3to8.3 {} {
+    global pcolorbar
+    switch $pcolorbar(orientation) {
+	horizontal {set pcolorbar(orientation) 0}
+	vertical {set pcolorbar(orientation) 1}
+    }
+
+    global colorbar
+    switch $colorbar(orientation) {
+	horizontal {set colorbar(orientation) 0}
+	vertical {set colorbar(orientation) 1}
+    }
+}
+
+proc FixPrefs8.2to8.3 {} {
+    global view
+    set view(multi) 0
+    
+    global pcolorbar
+    switch $pcolorbar(orientation) {
+	horizontal {set pcolorbar(orientation) 0}
+	vertical {set pcolorbar(orientation) 1}
+    }
+
+    global colorbar
+    switch $colorbar(orientation) {
+	horizontal {set colorbar(orientation) 0}
+	vertical {set colorbar(orientation) 1}
+    }
+
+    FixVar pgraph(thick) pgraph(horz,thick)
+    FixVar pgraph(log) pgraph(horz,log)
+    FixVar pgraph(grid) pgraph(horz,grid)
+    FixVar pgraph(method) pgraph(horz,method)
+
+    FixVar graph(thick) graph(horz,thick)
+    FixVar graph(log) graph(horz,log)
+    FixVar graph(grid) graph(horz,grid)
+    FixVar graph(method) graph(horz,method)
+}
+
+proc FixPrefs8.1to8.2 {} {
+    FixVar pap(canvas,layout) pap(layout)
+    FixVar pap(canvas,layout,strip,scale) pap(layout,strip,scale)
+
+    FixVar pap(canvas,foreground) pap(foreground)
+    FixVar pap(canvas,background) pap(background)
+    FixVar pap(canvas,grid,color) pap(grid,color)
+
+    FixVar pap(canvas,title,family) pap(title,family)
+    FixVar pap(canvas,title,size) pap(title,size)
+    FixVar pap(canvas,title,weight) pap(title,weight)
+    FixVar pap(canvas,title,slant) pap(title,slant)
+
+    FixVar pap(canvas,legend,title,family) pap(legend,title,family)
+    FixVar pap(canvas,legend,title,size) pap(legend,title,size)
+    FixVar pap(canvas,legend,title,weight) pap(legend,title,weight)
+    FixVar pap(canvas,legend,title,slant) pap(legend,title,slant)
+    FixVar pap(canvas,legend,font,family) pap(legend,font,family)
+    FixVar pap(canvas,legend,font,size) pap(legend,font,size)
+    FixVar pap(canvas,legend,font,weight) pap(legend,font,weight)
+    FixVar pap(canvas,legend,font,slant) pap(legend,font,slant)
+
+    FixVar pap(canvas,axis,title,family) pap(axis,title,family)
+    FixVar pap(canvas,axis,title,size) pap(axis,title,size)
+    FixVar pap(canvas,axis,title,weight) pap(axis,title,weight)
+    FixVar pap(canvas,axis,title,slant) pap(axis,title,slant)
+    FixVar pap(canvas,axis,font,family) pap(axis,font,family)
+    FixVar pap(canvas,axis,font,size) pap(axis,font,size)
+    FixVar pap(canvas,axis,font,weight) pap(axis,font,weight)
+    FixVar pap(canvas,axis,font,slant) pap(axis,font,slant)
+
+    FixVar pap(graph,ds,line,smooth) pap(graph,ds,smooth)
+    FixVar pap(graph,ds,line,color) pap(graph,ds,color)
+    FixVar pap(graph,ds,line,width) pap(graph,ds,width)
+    FixVar pap(graph,ds,line,dash) pap(graph,ds,dash)
+    FixVar pap(graph,ds,line,fill) pap(graph,ds,fill)
+    FixVar pap(graph,ds,line,fill,color) pap(graph,ds,fill,color)
+
+    FixVar pap(graph,ds,line,shape,symbol) pap(graph,ds,shape,symbol)
+    FixVar pap(graph,ds,line,shape,color) pap(graph,ds,shape,color)
+    FixVar pap(graph,ds,line,shape,fill) pap(graph,ds,shape,fill)
+
+    FixVarRm pap(graph,ds,bar,relief)
 }
 
 proc FixPrefs8.0to8.1 {} {
@@ -613,8 +755,6 @@ proc FixPrefs8.0to8.1 {} {
     FixVar pap(graph,ds,error,style) pap(error,style)
 
     FixVar pap(graph,ds,bar,relief) pap(relief)
-
-    FixVarRm pbuttons(file,samp)
 }
 
 proc FixPrefs7.6to8.0 {} {
@@ -626,8 +766,6 @@ proc FixPrefs7.5to7.6 {} {
     set smooth(radius,minor) $smooth(radius)
     set smooth(sigma) [expr int($smooth(radius)/2.)]
     set smooth(sigma,minor) $smooth(sigma)
-
-    FixVarRm pbuttons(help,keyboard)
 }
 
 proc FixPrefs7.4to7.5 {} {
@@ -738,9 +876,6 @@ proc FixPrefs7.0to7.1 {} {
 	unset pap(grid)
 	unset pap(grid,log)
     }
-
-    FixVarRm pbuttons(file,about)
-    FixVarRm pbuttons(help,home)
 }
 
 proc FixPrefs6.2to7.0 {} {
@@ -779,10 +914,6 @@ proc FixPrefs6.2to7.0 {} {
     FixVarRm pmarker(dialog,dist,system)
     FixVarRm pmarker(dialog,dist,format)
 
-    FixVarRm pbuttons(file,savefits)
-    FixVarRm pbuttons(file,savempeg)
-    FixVarRm pbuttons(region,circle3d)
-
     # mousewheel MacOSX Lion
     global tcl_platform
     global ppanzoom
@@ -1121,10 +1252,7 @@ proc FixPrefs5.xto6.0 {} {
                     color -
                     region -
                     wcs -
-                    help {
-			set pbuttons($nn) $buttons($nn)
-			unset buttons($nn)
-		    }
+                    help {unset buttons($nn)}
                 }
             }
         }
@@ -1144,7 +1272,5 @@ proc FixPrefs5.xto6.0 {} {
         FixVarRm pbuttons(zoom,1/8)
         FixVarRm pbuttons(zoom,1/4)
         FixVarRm pbuttons(zoom,1/2)
-
-	FixVarRm pbuttons(help,issue)
     }
 }
