@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2020
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -48,11 +48,13 @@ proc PrismDialog {varname} {
     set var(fn) {}
     set var(rows) 0
     set var(type) fits
+    set var(offset) 0
     set var(load) mmapincr
     set var(ext) 0
     set var(extname) {}
     set var(extnames) {}
     set var(extnum) 0
+    set var(search) {}
 
     set var(canvas,theme) $pap(canvas,theme)
 
@@ -66,7 +68,7 @@ proc PrismDialog {varname} {
     set var(yerr) {}
 
     set var(graph,ds,line,color) blue
-    set var(graph,ds,line,width) 1
+    set var(graph,ds,line,width) 0
     set var(graph,ds,line,dash) 0
     set var(graph,ds,line,shape,symbol) circle
     set var(graph,ds,line,shape,color) blue
@@ -109,6 +111,7 @@ proc PrismDialog {varname} {
 	-command [list PrismLoadFile $varname] -accelerator "${ds9(ctrl)}O"
     $mb.file add separator
     $mb.file add cascade -label [msgcat::mc {Import}] -menu $mb.file.import
+    $mb.file add cascade -label [msgcat::mc {Export}] -menu $mb.file.export
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Image}] \
 	-command [list PrismImage $varname]
@@ -127,6 +130,15 @@ proc PrismDialog {varname} {
     $mb.file.import add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
 	-command [list PrismImportTSVFile $varname]
 
+    # Export
+    ThemeMenu $mb.file.export
+    $mb.file.export add command -label "[msgcat::mc {VOTable}]..." \
+	-command [list TBLSaveVOTFile $varname]
+    $mb.file.export add command -label "[msgcat::mc {Starbase}]..." \
+	-command [list TBLSaveRDBFile $varname]
+    $mb.file.export add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
+	-command [list TBLSaveTSVFile $varname]
+
     ThemeMenu $mb.edit
     $mb.edit add command -label [msgcat::mc {Cut}] \
 	-state disabled -accelerator "${ds9(ctrl)}X"
@@ -196,8 +208,7 @@ proc PrismDialog {varname} {
     bind $var(dir) <<TreeviewSelect>> [list PrismExtCmd $varname]
 
     # Header
-    set f [ttk::labelframe $p.header -padding {0 2} \
-	       -text [msgcat::mc {Header Keywords}]]
+    set f [ttk::labelframe $p.header -padding {0 2} -text [msgcat::mc {Header}]]
 
     set var(text) $f.text
     roText::roText $var(text)
@@ -266,7 +277,7 @@ proc PrismDialog {varname} {
 	-fg [ThemeSelectedForeground] -bg [ThemeSelectedBackground]
     $var(tbl) tag configure title \
 	-fg [ThemeForeground] -bg [ThemeBackground] -bd 0
-    $prism(tbl) width 0 7
+    $var(tbl) width 0 8
     
     ttk::scrollbar $f.xscroll -command [list $var(tbl) xview] -orient horizontal
     ttk::scrollbar $f.yscroll -command [list $var(tbl) yview] -orient vertical
@@ -586,21 +597,29 @@ proc PrismImportFn {varname fn reader} {
     $reader $var(tbldb) $fn
 
     $var(tbl) configure -titlerows 1
+    set var(offset) 0
+
+    # starbase_ncols is just cols
+    # configure cols includes extra row
     set nc [starbase_ncols $var(tbldb)]
-    if {$nc > $iprism(mincols)} {
-	$var(tbl) configure -cols $nc
+    set cc [expr $nc+1]
+    if {$cc > $iprism(mincols)} {
+	$var(tbl) configure -cols $cc
     } else {
 	$var(tbl) configure -cols $iprism(mincols)
     }
 
+    # starbase_nrows is just rows
+    # configure rows includes all header
     set nr [starbase_nrows $var(tbldb)]
-    if {$nr > $iprism(minrows)} {
-	$var(tbl) configure -rows [expr $nr+1]
+    set cc [expr $nr+1]
+    if {$cc > $iprism(minrows)} {
+	$var(tbl) configure -rows $cc
     } else {
 	$var(tbl) configure -rows $iprism(minrows)
     }
     set var(rows) $nr
-
+    
     set info \
 	"[starbase_ncols $var(tbldb)] cols, [starbase_nrows $var(tbldb)] rows"
     $var(dir) insert {} end -id 0 -values [list [file tail $fn] "Table" "$info"]
@@ -617,6 +636,8 @@ proc PrismImportFn {varname fn reader} {
 	set $var(tbldb)($ii,0) $ii
     }
 
+    $var(tbl) see 1,1
+
     # need this so that PrismExtCmd is invoked before next command
     update
     
@@ -639,6 +660,7 @@ proc PrismClear {varname} {
     set var(fn) {}
     set var(rows) 0
     set var(type) fits
+    set var(offset) 0
     set var(load) {}
     set var(ext) 0
     set var(extname) {}
@@ -1752,30 +1774,43 @@ proc PrismTableFits {varname} {
 
 	$var(tbl) configure -rows $iprism(minrows)
 	$var(tbl) configure -titlerows 1
+	set var(offset) 0
 
 	PrismDialogUpdate $varname
 	return
     }
 
-    # init db
-    fitsy table $var(tbldb) true $var(start) $iprism(block)
+    set t $var(tbldb)
+    upvar #0 $t T
+    global $t
+
+    fitsy table $t true $var(start) $iprism(block)
     fitsy close
     
-    $var(tbl) configure -titlerows 2
-
-    set t $var(tbldb)
+    set T(HLines) 2
+    set T(H_1) $T(Header)
+    set T(H_2) [regsub -all {[A-Za-z0-9]} $T(Header) {-}]
     starbase_colmap $t
 
+    $var(tbl) configure -titlerows 2
+    set var(offset) 1
+
+    # starbase_ncols is just cols
+    # configure cols includes extra row
     set nc [starbase_ncols $t]
-    if {$nc > $iprism(mincols)} {
-	$var(tbl) configure -cols $nc
+    set cc [expr $nc+1]
+    if {$cc > $iprism(mincols)} {
+	$var(tbl) configure -cols $cc
     } else {
 	$var(tbl) configure -cols $iprism(mincols)
     }
 
+    # starbase_nrows includes 1 extra header
+    # configure rows includes all header
     set nr [starbase_nrows $t]
-    if {$nr > $iprism(minrows)} {
-	$var(tbl) configure -rows [expr $nr+1]
+    set cc [expr $nr-1+2]
+    if {$cc > $iprism(minrows)} {
+	$var(tbl) configure -rows $cc
     } else {
 	$var(tbl) configure -rows $iprism(minrows)
     }
@@ -1789,6 +1824,9 @@ proc PrismTableFits {varname} {
 
     $var(tbl) see 2,1
 
+    # need this so that PrismExtCmd is invoked before next command
+    update
+
     PrismDialogUpdate $varname
 }
 
@@ -1951,6 +1989,10 @@ proc PrismExtFitsCmd {varname} {
 proc PrismExtAsciiCmd {varname} {
     upvar #0 $varname var
     global $varname
+
+    # header
+    $var(text) delete 1.0 end
+    $var(text) insert end [TBLGetHeader $varname]
 }
 
 # Process Cmds
@@ -2020,6 +2062,9 @@ proc PrismCmdLoad {fn} {
 proc PrismCmdExt {ext} {
     global iprism
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     
     if {$ext >= 0 && $ext <= $cvar(extnum)} {
@@ -2035,6 +2080,9 @@ proc PrismCmdExt {ext} {
 proc PrismCmdExtName {extname} {
     global iprism
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
     
     set ext [lsearch $cvar(extnames) $extname]
@@ -2052,16 +2100,20 @@ proc PrismCmdExtName {extname} {
 
 proc PrismBackup {ch dir} {
     global iprism
-    global pds9
 
     foreach ww $iprism(prisms) {
 	set varname $ww
 	upvar #0 $varname var
 	global $varname
-
+	
+	# if we have no filename, don't save
+	if {$var(fn) == {}} {
+	    continue
+	}
+    
 	set fdir [file join $dir $ww]
 	set rdir "./[lindex [file split $dir] end]/$ww"
-	
+    
 	# create dir if needed
 	if {![file isdirectory $fdir]} {
 	    if {[catch {file mkdir $fdir}]} {
@@ -2071,52 +2123,72 @@ proc PrismBackup {ch dir} {
 	}
 
 	puts $ch "PrismDialog $varname"
-	if {$var(fn) != {}} {
-	    set fn $var(fn)
 
-	    # check for extension
-	    set id [string first "\[" $var(fn)]
-	    if {$id > 0} {
-		set fn [string range $var(fn) 0 [expr $id-1]]
-		set ext [string range $var(fn) $id end]
-	    } else {
-		set fn $var(fn)
-		set ext {}
-	    }
-
-	    if {![file exists $fn]} {
-		return 0
-	    }
-
-	    if {$pds9(backup)} {
-		# look for sym links
-		switch [file type $fn] {
-		    file {}
-		    link {set fn [file join [file dirname $fn] [file readlink $fn]]}
-		    default {
-			return 0
-		    }
-		}
-
-		set src [lindex [file split $fn] end]
-		if {![file exists [file join $fdir $src]]} {
-		    if {[catch {file copy $var(fn) $fdir}]} {
-			return 0
-		    }
-		}
-		puts $ch "PrismLoad $varname $rdir/[file tail $fn]"
-	    } else {
-		if {[file pathtype $fn] == {relative}} {
-		    puts $ch "PrismLoad $varname [file join [pwd] $fn]"
-		} else {
-		    puts $ch "PrismLoad $varname $fn"
-		}
-	    }
-	}
-
-	if {$var(ext) > 0} {
-	    puts $ch "PrismSetExt $varname $var(ext)"
+	switch $var(type) {
+	    fits {PrismBackupFits $varname $ch $fdir $rdir}
+	    ascii {PrismBackupAscii $varname $ch $fdir $rdir}
 	}
     }
 }
 
+proc PrismBackupFits {varname ch fdir rdir} {
+    upvar #0 $varname var
+    global $varname
+
+    set fn $var(fn)
+
+    # check for extension
+    set id [string first "\[" $var(fn)]
+    if {$id > 0} {
+	set fn [string range $var(fn) 0 [expr $id-1]]
+	set ext [string range $var(fn) $id end]
+    } else {
+	set fn $var(fn)
+	set ext {}
+    }
+
+    if {![file exists $fn]} {
+	return
+    }
+
+    global pds9
+    if {$pds9(backup)} {
+	# look for sym links
+	switch [file type $fn] {
+	    file {}
+	    link {set fn [file join [file dirname $fn] [file readlink $fn]]}
+	    default {
+		return
+	    }
+	}
+
+	set src [lindex [file split $fn] end]
+	if {![file exists [file join $fdir $src]]} {
+	    if {[catch {file copy $var(fn) $fdir}]} {
+		return
+	    }
+	}
+	puts $ch "PrismLoad $varname $rdir/[file tail $fn]"
+    } else {
+	if {[file pathtype $fn] == {relative}} {
+	    puts $ch "PrismLoad $varname [file join [pwd] $fn]"
+	} else {
+	    puts $ch "PrismLoad $varname $fn"
+	}
+    }
+
+    if {$var(ext) > 0} {
+	puts $ch "PrismSetExt $varname $var(ext)"
+    }
+}
+
+proc PrismBackupAscii {varname ch fdir rdir} {
+    upvar #0 $varname var
+    global $varname
+
+    set fn [file rootname [file tail $var(fn)]]
+    append fn {.xml}
+
+    VOTWrite $var(tbldb) $fdir/$fn
+    puts $ch "PrismImportFn $varname $rdir/$fn VOTRead"
+}
