@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -39,14 +39,10 @@ proc SAMPConnect {{verbose 1}} {
     set samp(apps,image) {}
     set samp(apps,table) {}
     set samp(apps,votable) {}
+    set samp(tmp,files) {}
 
     # these are to try to prevent feedback problems with 
-    # other probgrams
-    set samp(rcvd,lock) 0
-    set samp(send,lock) 0
-
-    # delete any old tmp files
-    SAMPDelTmpFiles
+    set samp(lock) 0
 
     # can we find a hub?
     if {![SAMPParseHub]} {
@@ -221,21 +217,14 @@ proc SAMPSendImageLoadFits {id} {
 	return
     }
 
-    # are we locked?
-    if {$samp(rcvd,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Rcvd locked"
-	}
-	return
-    }
-
     # got something to send?
     if {![$current(frame) has fits]} {
 	return
     }
 
     # save current frame
-    set fn [tmpnam {.samp}]
+    set fn [tmpnam {.fits}]
+    lappend samp(tmp,files) $fn
     catch {$current(frame) save fits image file "\{$fn\}"}
 
     # name to use
@@ -272,10 +261,6 @@ proc SAMPSendImageLoadFits {id} {
 	    Error "SAMP: [msgcat::mc {internal error}] $rr"
 	}
     }
-
-    # set lock
-    set samp(send,lock) 1
-    after $isamp(timeout) SAMPClearSendLock
 }
 
 proc SAMPSendTableLoadFits {id} {
@@ -297,21 +282,14 @@ proc SAMPSendTableLoadFits {id} {
 	return
     }
 
-    # are we locked?
-    if {$samp(rcvd,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Rcvd locked"
-	}
-	return
-    }
-
     # got something to send?
     if {![$current(frame) has fits] && [$current(frame) has fits bin]} {
 	return
     }
 
     # save current frame
-    set fn [tmpnam {.samp}]
+    set fn [tmpnam {.fits}]
+    lappend samp(tmp,files) $fn
     catch {$current(frame) save fits table file "\{$fn\}"}
 
     # name to use
@@ -348,10 +326,6 @@ proc SAMPSendTableLoadFits {id} {
 	    Error "SAMP: [msgcat::mc {internal error}] $rr"
 	}
     }
-
-    # set lock
-    set samp(send,lock) 1
-    after $isamp(timeout) SAMPClearSendLock
 }
 
 proc SAMPSendTableLoadVotable {id varname} {
@@ -375,20 +349,13 @@ proc SAMPSendTableLoadVotable {id varname} {
 	return
     }
 
-    # are we locked?
-    if {$samp(rcvd,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Rcvd locked"
-	}
-	return
-    }
-
     # remember
     set samp(icat,$varname$samp(port)) $varname
     set samp(ocat,$varname) $varname$samp(port)
 
     # save votable
-    set fn [tmpnam {.samp}]
+    set fn [tmpnam {.xml}]
+    lappend samp(tmp,files) $fn
     TBLSaveFn $varname $fn VOTWrite
 
     # cmd
@@ -420,10 +387,31 @@ proc SAMPSendTableLoadVotable {id varname} {
 	    Error "SAMP: [msgcat::mc {internal error}] $rr"
 	}
     }
+}
 
-    # set lock
-    set samp(send,lock) 1
-    after $isamp(timeout) SAMPClearSendLock
+proc SAMPSendTableRowListCmd {varname rowlist} {
+    global ds9
+    global samp
+
+    # connected?
+    if {![info exists samp]} {
+	return
+    }
+
+    if {$samp(apps,votable) == {}} {
+	return
+    }
+
+    # are we good?
+    if {![info exists samp(ocat,$varname)]} {
+	return
+    }
+
+    switch -- [llength $rowlist] {
+	0 {}
+	1 {SAMPSendTableHighlightRow {} $varname $rowlist}
+	default {SAMPSendTableSelectRowList {} $varname $rowlist}
+    }
 }
 
 proc SAMPSendTableHighlightRow {id varname row} {
@@ -468,10 +456,6 @@ proc SAMPSendTableHighlightRow {id varname row} {
 	    Error "SAMP: [msgcat::mc {internal error}] $rr"
 	}
     }
-
-    # set lock
-    set samp(send,lock) 1
-    after $isamp(timeout) SAMPClearSendLock
 }
 
 proc SAMPSendTableSelectRowList {id varname rows} {
@@ -520,13 +504,9 @@ proc SAMPSendTableSelectRowList {id varname rows} {
 	    Error "SAMP: [msgcat::mc {internal error}] $rr"
 	}
     }
-
-    # set lock
-    set samp(send,lock) 1
-    after $isamp(timeout) SAMPClearSendLock
 }
 
-proc SAMPSendTableRowListCmd {varname rowlist} {
+proc SAMPSendCoordPointAtSkyCmd {which} {
     global ds9
     global samp
 
@@ -535,28 +515,24 @@ proc SAMPSendTableRowListCmd {varname rowlist} {
 	return
     }
 
-    if {$samp(apps,votable) == {}} {
-	return
-    }
-
-    # are we good?
-    if {![info exists samp(ocat,$varname)]} {
-	return
-    }
-
     # are we locked?
-    if {$samp(rcvd,lock)} {
+    if {$samp(lock)} {
 	global debug
 	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Rcvd locked"
+	    puts stderr "SAMP: SAMPSendCoordPointAtSkyCmd: ABORT locked"
 	}
 	return
     }
 
-    switch -- [llength $rowlist] {
-	0 {}
-	1 {SAMPSendTableHighlightRow {} $varname $rowlist}
-	default {SAMPSendTableSelectRowList {} $varname $rowlist}
+    if {$samp(apps,image) == {} || $samp(apps,table) == {}} {
+	return
+    }
+
+    if {[$which has wcs celestial wcs]} {
+	set coord [$which get coordinates [$which get cursor canvas] wcs fk5 degrees]
+	if {$coord != {}} {
+	    SAMPSendCoordPointAtSky {} "$coord"
+	}
     }
 }
 
@@ -598,40 +574,6 @@ proc SAMPSendCoordPointAtSky {id coord} {
 	    Error "SAMP: [msgcat::mc {internal error}] $rr"
 	}
     }
-
-    # set lock
-    set samp(send,lock) 1
-    after $isamp(timeout) SAMPClearSendLock
-}
-
-proc SAMPSendCoordPointAtSkyCmd {which} {
-    global ds9
-    global samp
-
-    # connected?
-    if {![info exists samp]} {
-	return
-    }
-
-    # are we locked?
-    if {$samp(rcvd,lock)} {
-	global debug
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Rcvd locked"
-	}
-	return
-    }
-
-    if {$samp(apps,image) == {} || $samp(apps,table) == {}} {
-	return
-    }
-
-    if {[$which has wcs celestial wcs]} {
-	set coord [$which get coordinates [$which get cursor canvas] wcs fk5 degrees]
-	if {$coord != {}} {
-	    SAMPSendCoordPointAtSky {} "$coord"
-	}
-    }
 }
 
 # Support
@@ -765,6 +707,7 @@ proc SAMPSend {method params resultVar} {
     if {$debug(tcl,samp)} {
 	puts stderr "SAMPSend Result: $result"
     }
+
     return 1
 }
 
@@ -831,33 +774,16 @@ proc SAMPReplySimple {msgid str} {
     }
 
     global samp
-
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     SAMPReply $msgid OK "$str"
 }
 
-proc SAMPClearSendLock {} {
-    global samp
-    global debug
-    if {$debug(tcl,samp)} {
-	puts stderr "SAMPClearSendLock"
-    }
-    set samp(send,lock) 0
-}
-
 # receiveNotification(string sender-id, map message)
 proc samp.client.receiveNotification {args} {
     global debug
     if {$debug(tcl,samp)} {
 	puts stderr "SAMPReceivedNotification: $args"
     }
+    
     set secret [lindex $args 0]
     set id [lindex $args 1]
     set map [lindex $args 2]
@@ -873,6 +799,9 @@ proc samp.client.receiveNotification {args} {
 	}
     }
 
+    # be sure to lock any command that may cause a
+    #   SAMPSendCoordPointAtSkyCmd response
+    global samp
     switch -- $mtype {
 	samp.hub.event.shutdown {
 	    SAMPRcvdEventShutdown params
@@ -887,28 +816,42 @@ proc samp.client.receiveNotification {args} {
 	    SAMPRcvdDisconnect params
 	}
 	image.load.fits {
+	    set samp(lock) 1
 	    SAMPRcvdImageLoadFits params
+	    set samp(lock) 0
 	}
 	table.load.fits {
+	    set samp(lock) 1
 	    SAMPRcvdTableLoadFits params
+	    set samp(lock) 0
 	}
 	table.load.votable {
 	    SAMPRcvdTableLoadVotable params
 	}
 	table.highlight.row {
+	    set samp(lock) 1
 	    SAMPRcvdTableHighlightRow params
+	    set samp(lock) 0
 	}
 	table.select.rowList {
+	    set samp(lock) 1
 	    SAMPRcvdTableSelectRowList params
+	    set samp(lock) 0
 	}
 	coord.pointAt.sky {
+	    set samp(lock) 1
 	    SAMPRcvdCoordPointAtSky params
+	    set samp(lock) 0
 	}
 	ds9.set {
+	    set samp(lock) 1
 	    SAMPRcvdDS9Set {} params 0
+	    set samp(lock) 0
 	}
 	ds9.restricted-set {
+	    set samp(lock) 1
 	    SAMPRcvdDS9Set {} params 1
+	    set samp(lock) 0
 	}
 	default {
 	    if {$debug(tcl,samp)} {
@@ -916,13 +859,13 @@ proc samp.client.receiveNotification {args} {
 	    }
 	}
     }
+
     return {string OK}
 }
 
 # receiveCall(string sender-id, string msg-id, map message)
 proc samp.client.receiveCall {args} {
     global ds9
-
     global debug
     if {$debug(tcl,samp)} {
 	puts stderr "SAMPReceivedCall: $args"
@@ -944,16 +887,23 @@ proc samp.client.receiveCall {args} {
 	}
     }
 
+    # be sure to lock any command that may cause a
+    #   SAMPSendCoordPointAtSkyCmd response
+    global samp
     switch -- $mtype {
 	samp.app.ping {
 	    SAMPReply $msgid OK
 	}
 	image.load.fits {
+	    set samp(lock) 1
 	    SAMPRcvdImageLoadFits params
+	    set samp(lock) 0
 	    SAMPReply $msgid OK
 	}
 	table.load.fits {
+	    set samp(lock) 1
 	    SAMPRcvdTableLoadFits params
+	    set samp(lock) 0
 	    SAMPReply $msgid OK
 	}
 	table.load.votable {
@@ -961,15 +911,21 @@ proc samp.client.receiveCall {args} {
 	    SAMPReply $msgid OK
 	}
 	table.highlight.row {
+	    set samp(lock) 1
 	    SAMPRcvdTableHighlightRow params
+	    set samp(lock) 0
 	    SAMPReply $msgid OK
 	}
 	table.select.rowList {
+	    set samp(lock) 1
 	    SAMPRcvdTableSelectRowList params
+	    set samp(lock) 0
 	    SAMPReply $msgid OK
 	}
 	coord.pointAt.sky {
+	    set samp(lock) 1
 	    SAMPRcvdCoordPointAtSky params
+	    set samp(lock) 0
 	    SAMPReply $msgid OK
 	}
 	client.env.get {
@@ -998,16 +954,24 @@ proc samp.client.receiveCall {args} {
 	    SAMPReplySimple $msgid OK "$ds9(version,display)"
 	}
 	ds9.get {
+	    set samp(lock) 1
 	    SAMPRcvdDS9Get $msgid params
+	    set samp(lock) 0
 	}
 	ds9.set {
+	    set samp(lock) 1
 	    SAMPRcvdDS9Set $msgid params 0
+	    set samp(lock) 0
 	}
 	ds9.restricted-get {
+	    set samp(lock) 1
 	    SAMPRcvdDS9Get $msgid params
+	    set samp(lock) 0
 	}
 	ds9.restricted-set {
+	    set samp(lock) 1
 	    SAMPRcvdDS9Set $msgid params 1
+	    set samp(lock) 0
 	}
 	default {
 	    SAMPReply $msgid ERROR {} {} "[msgcat::mc {Unknown command}]: $mtype"
@@ -1016,6 +980,7 @@ proc samp.client.receiveCall {args} {
 	    }
 	}
     }
+
     return {string OK}
 }
 
@@ -1050,6 +1015,7 @@ proc SAMPParseHub {} {
 		switch -- $rr(scheme) {
 		    ftp {
 			set fn [tmpnam {.samp}]
+			lappend samp(tmp,files) $fn
 			GetFileFTP $rr(authority) $rr(path) $fn
 		    }
 		    file {set fn $rr(path)}
@@ -1057,6 +1023,7 @@ proc SAMPParseHub {} {
 		    https -
 		    default {
 			set fn [tmpnam {.samp}]
+			lappend samp(tmp,files) $fn
 			GetFileHTTP $url $fn
 		    }
 		}
@@ -1253,14 +1220,6 @@ proc SAMPRcvdImageLoadFits {varname} {
     global current
     global samp
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set url {}
     set imageid {}
     set name {}
@@ -1296,14 +1255,6 @@ proc SAMPRcvdTableLoadFits {varname} {
     global current
     global samp
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set url {}
     set imageid {}
     set name {}
@@ -1337,14 +1288,6 @@ proc SAMPRcvdTableLoadVotable {varname} {
 	puts stderr "SAMPRcvdTableLoadVotable: $args"
     }
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set url {}
     set tabid {}
     set name {}
@@ -1383,14 +1326,6 @@ proc SAMPRcvdTableHighlightRow {varname} {
 	puts stderr "SAMPRcvdTableHighlightRow: $args"
     }
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set url {}
     set tabid {}
     set row {}
@@ -1411,7 +1346,7 @@ proc SAMPRcvdTableHighlightRow {varname} {
 
     if {$tabid != {} && $row != {}} {
 	if {[info exists samp(icat,$tabid)]} {
-	    CATSelectRows $samp(icat,$tabid) samp [expr $row+1]
+	    CATSelectRows $samp(icat,$tabid) samp [expr $row+1] 1
 	}
     }
 }
@@ -1425,14 +1360,6 @@ proc SAMPRcvdTableSelectRowList {varname} {
 	puts stderr "SAMPRcvdTableSelectRowList: $args"
     }
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set url {}
     set tabid {}
     set rowlist {}
@@ -1457,7 +1384,7 @@ proc SAMPRcvdTableSelectRowList {varname} {
 
     if {$tabid != {} && [llength $rowlist] != 0} {
 	if {[info exists samp(icat,$tabid)]} {
-	    CATSelectRows $samp(icat,$tabid) samp $rowlist
+	    CATSelectRows $samp(icat,$tabid) samp $rowlist 1
 	}
     }
 }
@@ -1471,14 +1398,6 @@ proc SAMPRcvdCoordPointAtSky {varname} {
 	puts stderr "SAMPRcvdCoordPointAtSky: $args"
     }
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set ra {}
     set dec {}
 
@@ -1497,9 +1416,7 @@ proc SAMPRcvdCoordPointAtSky {varname} {
 
     global current
     if {$ra != {} && $dec != {} && [$current(frame) has wcs celestial wcs]} {
-	set samp(rcvd,lock) 1
 	PanTo $ra $dec wcs fk5
-	set samp(rcvd,lock) 0
     }
 }
 
@@ -1512,14 +1429,6 @@ proc SAMPRcvdClientEnvGet {msgid varname} {
 	puts stderr "SAMPRcvdClientEnvGet: $msgid $args"
     }
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set name {}
 
     foreach arg $args {
@@ -1555,14 +1464,6 @@ proc SAMPRcvdDS9Set {msgid varname safemode} {
     global current
     global samp
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set url {}
     set cmd {}
 
@@ -1579,7 +1480,8 @@ proc SAMPRcvdDS9Set {msgid varname safemode} {
 
     InitError samp
     if {$url != {}} {
-	set fn [tmpnam {.samp}]
+	set fn [tmpnam {.xpa}]
+	lappend samp(tmp,files) $fn
 	GetFileURL $url fn
     }
     CommSet $fn $cmd $safemode
@@ -1626,14 +1528,6 @@ proc SAMPRcvdDS9Get {msgid varname} {
     global current
     global samp
 
-    # are we locked?
-    if {$samp(send,lock)} {
-	if {$debug(tcl,samp)} {
-	    puts stderr "SAMP: ABORT Send locked"
-	}
-	return
-    }
-
     set url {}
     set cmd {}
 
@@ -1646,7 +1540,8 @@ proc SAMPRcvdDS9Get {msgid varname} {
 	}
     }
 
-    set fn [tmpnam {.samp}]
+    set fn [tmpnam {.xpa}]
+    lappend samp(tmp,files) $fn
     InitError samp
     CommGet SAMPRcvdDS9GetReply $msgid $cmd $fn
 }
@@ -1688,10 +1583,10 @@ proc SAMPRcvdDS9GetReply {msgid msg {fn {}}} {
 }
 
 proc SAMPDelTmpFiles {} {
-    global ds9
+    global samp
 
-    # delete any previous files
-    foreach fn [glob -directory $ds9(tmpdir) -nocomplain {ds9*samp*}] {
+    # delete any tmp files
+    foreach fn $samp(tmp,files) {
 	catch {file delete -force "$fn"}
     }
 }
@@ -1722,6 +1617,16 @@ proc ProcessSAMPCmd {varname iname} {
     incr i [expr $samp::yycnt-1]
 }
 
+proc ProcessSendSAMPCmd {proc id param {sock {}} {fn {}}} {
+    global samp
+
+    if {[info exists samp]} {
+	$proc $id "yes\n"
+    } else {
+	$proc $id "no\n"
+    }
+}
+
 proc SAMPCmdSendImage {name} {
     global samp
 
