@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -176,7 +176,6 @@ proc UpdateScale {} {
     UpdateScaleMenu
     UpdateScaleDialog
     UpdateContourScale
-    UpdateGraphAxis $current(frame)
     UpdateInfoBoxFrame $current(frame)
     UpdateMain
 }
@@ -341,9 +340,10 @@ proc ScaleDialog {} {
 	-color [ThemeTreeForeground] \
 	-titlecolor [ThemeTreeForeground]
 
-    set dscale(xdata) histX
-    set dscale(ydata) histY
+    set dscale(xdata) scaleHistX
+    set dscale(ydata) scaleHistY
     blt::vector create $dscale(xdata) $dscale(ydata)
+
     $dscale(hist) element create bar1 \
 	-smooth step  \
 	-xdata $dscale(xdata) \
@@ -451,6 +451,7 @@ proc ScaleDestroyDialog {} {
 	destroy $iscale(top)
 	destroy $iscale(mb)
 	blt::vector destroy $dscale(xdata) $dscale(ydata)
+	destroy $dscale(hist)
 	unset dscale
     }
 }
