@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -67,13 +67,10 @@ proc TBLGetURLFinish {varname token} {
 
     # Result?
     switch -- $code {
-	{} -
 	200 -
 	203 -
 	404 -
-	503 {
-	    eval [list $var(proc,process) $varname]
-	}
+	503 {eval [list $var(proc,exec) $varname]}
 
 	201 -
 	300 -
@@ -447,8 +444,11 @@ proc TBLSaveFn {varname fn writer} {
 	return
     }
 
-    $writer $var(tbldb) $fn
-    ARDone $varname
+    if {[info exists var(offset)]} {
+	$writer $var(tbldb) $fn $var(offset)
+    } else {
+	$writer $var(tbldb) $fn
+    }
 }
 
 # Sort
@@ -751,10 +751,34 @@ proc TBLEditDialogLoad {parent} {
     }
 }
 
+proc TBLGetHeader {varname} {
+    upvar #0 $varname var
+    global $varname
+    global $var(tbldb)
+
+    set t $var(tbldb)
+    upvar #0 $t T
+
+    if {![TBLValidDB $var(tbldb)]} {
+	return {}
+    }
+
+    # last 2 lines are cols and dashes, ignore
+    set hdr {}
+    set nl [expr $T(HLines)-2]
+    for {set ll 1} {$ll <= $nl} {incr ll} {
+	append hdr "$T(H_$ll)\n"
+    }
+    return $hdr
+}
+
 # Cmd
 
 proc TBLCmdSave {fn writer} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
 
     if {$fn != {}} {
 	TBLSaveFn $cvarname $fn $writer
@@ -764,6 +788,9 @@ proc TBLCmdSave {fn writer} {
 
 proc TBLCmdCoord {xx yy sky} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
 
     set cvar(x) $xx
@@ -773,6 +800,9 @@ proc TBLCmdCoord {xx yy sky} {
 
 proc TBLCmdSize {radius rformat} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
 
     set cvar(radius) $radius
@@ -782,6 +812,9 @@ proc TBLCmdSize {radius rformat} {
 
 proc TBLCmdSkyframe {skyframe} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
 
     set cvar(sky) $skyframe
@@ -790,6 +823,9 @@ proc TBLCmdSkyframe {skyframe} {
 
 proc TBLCmdSystem {sys} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
 
     set cvar(system) $sys
@@ -798,6 +834,9 @@ proc TBLCmdSystem {sys} {
 
 proc TBLCmdFilterLoad {fn} {
     global cvarname
+    if {$cvarname == {}} {
+	return
+    }
     upvar #0 $cvarname cvar
 
     if {$fn != {}} {
@@ -817,19 +856,6 @@ proc TBLCmdFilterLoad {fn} {
 proc TBLPrint {varname} {
     upvar #0 $varname var
     global $varname
-    global $var(tbldb)
-
-    global ds9
-    switch $ds9(wm) {
-	x11 -
-	aqua -
-	win32 {TBLPSPrint $varname}
-    }	
-}
-
-proc TBLPSPrint {varname} {
-    upvar #0 $varname var
-    global $varname
 
     if {[PRPrintDialog]} { 
 	if {[catch {TBLPostScript $varname} printError]} {
@@ -846,11 +872,16 @@ proc TBLPostScript {varname} {
     global ps
 
     if {$ps(dest) == "file"} {
-	set ch [open "| cat > $ps(filename,txt)" w]
+	if {[catch {set ch [open "$ps(filename,txt)" w]}]} {
+	    Error [msgcat::mc {An error has occurred while saving}]
+	    return
+	}
     } else {
-	set ch [open "| $ps(cmd)" w]
+	if {[catch {set ch [open "| $ps(cmd)" w]}]} {
+	    Error [msgcat::mc {An error has occurred while saving}]
+	    return
+	}
     }
-
     starbase_writefp $var(tbldb) $ch
     close $ch
 }
