@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -10,8 +10,8 @@ proc CurrentDef {} {
     global ds9
 
     set current(frame) {}
-    set current(ext) {}
     set current(colorbar) {}
+    set current(ext) {}
     set current(cursor) {}
     set current(rgb) red
 
@@ -89,6 +89,7 @@ proc UpdateDS9 {} {
     # wcs(system) set here
     UpdateWCSMenu 
     UpdateAnalysisMenu
+    UpdateAnalysisButtonbar
 
     UpdateMaskMenu
     UpdateContourMenu
@@ -116,8 +117,6 @@ proc UpdateDS9 {} {
     UpdateContourDialog
     UpdateGridDialog
 
-    UpdateGraphAxis $current(frame)
-
     RefreshInfoBox $current(frame)
     UpdateColormapLevel
     
@@ -147,7 +146,7 @@ proc UpdateMain {} {
 		# just in case we have a mosaic
 		UpdateColormapLevelMosaic $current(frame) $x $y canvas
 		UpdatePixelTableDialog $current(frame) $x $y canvas
-		UpdateGraphData $current(frame) $x $y canvas
+		UpdateGraphsData $current(frame) $x $y canvas
 	    }
 	}
 	none -
@@ -647,27 +646,8 @@ proc InitFilterCompiler {} {
     # if the user did not explicitly specify one ...
     if {![info exists env(FILTER_CC)]} {
 	switch -- $ds9(wm) {
-	    x11 {}
-	    aqua {
-		if {![file exists /usr/bin/gcc]} {
- 		    # pcc is hardwired to be installed in /tmp
- 		    set pccroot "/tmp/pcc"
- 		    set pcc "$pccroot/bin/pcc"
- 		    set tar "pcc-i386-snowleopard.tar.gz"
-		    
- 		    if {[file readable "$ds9(root)/$tar"]} {
- 			exec cp "$ds9(root)/$tar" "/tmp/$tar"
- 			exec tar xfPz "/tmp/$tar" -C /tmp
- 			exec rm -f "/tmp/$tar"
- 		    }
-		    
- 		    if {[file exists $pcc]} {
- 			set env(FILTER_CC) $pcc
- 			set env(FILTER_CFLAGS) "-isystem $pccroot/lib/pcc"
- 			set env(PATH) "$pccroot/bin:$env(PATH)"
- 		    }
-		}
-	    }
+	    x11 -
+	    aqua {}
 	    win32 {
 		set tcc [file join $ds9(root) tcc/tcc.exe]
  		if {[file exists $tcc]} {
@@ -806,6 +786,19 @@ proc CursorTimer {} {
 }
 
 proc AboutBox {} {
+    global ds9
+    global pds9
+
+    switch $ds9(wm) {
+	x11 -
+	win32 {AboutBoxDefault}
+	aqua {
+	    ::tk::mac::standardAboutPanel
+	}
+    }
+}
+
+proc AboutBoxDefault {} {
     global help
     global ds9
     global ed
@@ -818,7 +811,7 @@ proc AboutBox {} {
 
     # Param
     set f [ttk::frame $w.param]
-    canvas $f.c -background white -height 450 -width 500
+    canvas $f.c -background white -height 300 -width 500
     pack $f.c -fill both -expand true
     
     set ed(sun) [image create photo -format gif -file $ds9(root)/doc/sun.gif]
@@ -934,13 +927,14 @@ proc ChangeMode {} {
 	$ff marker catalog unhighlite all
 	$ff marker unselect all
 	$ff marker unhighlite all
+
+	HideGraphsData $ff
     }
 
     UpdateRegionMenu
 
     RefreshInfoBox $current(frame)
     PixelTableClearDialog
-    ClearGraphData
 
     switch -- $current(mode) {
 	none -
@@ -951,6 +945,7 @@ proc ChangeMode {} {
 	crosshair {
 	    foreach ff $ds9(frames) {
 		$ff crosshair on
+		ShowGraphsData $ff
 	    }
 	    SetCursor crosshair
 	}
@@ -1040,7 +1035,6 @@ proc SetDefaultFont {which} {
 	global ifp
 
 	UpdateScaleDialogFont
-	UpdateGraphFont
 	TBLUpdateFont $icat(cats)
 	TBLUpdateFont $isia(sias)
 	TBLUpdateFont $ifp(fps)
@@ -1057,6 +1051,7 @@ proc SetDefaultTextFont {which} {
 
     if {$which} {
 	SimpleTextUpdateFont
+	EditTextUpdateFont
     }
 }
 
@@ -1225,12 +1220,17 @@ proc HTTPLog {token} {
 	DisplayLog "url: $t(url)\n"
 	DisplayLog "http: $t(http)\n"
 	DisplayLog "type: $t(type)\n"
+	DisplayLog "binary: $t(binary)\n"
+	DisplayLog "coding: $t(coding)\n"
 	DisplayLog "currentsize: $t(currentsize)\n"
 	DisplayLog "totalsize: $t(totalsize)\n"
 	DisplayLog "status: $t(status)\n"
 	if {[info exists t(error)]} {
 	    DisplayLog "error: $t(error)\n"
 	}
+	if {[info exists t(posterror)]} {
+	    DisplayLog "posterror: $t(posterror)\n"
+	}
 	DisplayLog "meta: [BreakUp $t(meta)]\n"
     }
 }
@@ -1369,7 +1369,7 @@ proc MacOSPhotoFix {top xx yy} {
     return {}
 }
 
-proc DarwinPhotoRestore {top geom} {
+proc MacOSPhotoRestore {top geom} {
     global ds9
     global tcl_platform
 
