@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -229,6 +229,11 @@ proc CreateXPA {} {
 	XPASendGIF {} {} \
 	XPARcvdGIF {} "fillbuf=false"
 
+    xpacmdadd $xpa graph \
+	{} \
+	XPASendGraph {} {} \
+	XPARcvdGraph {} "fillbuf=false"
+
     xpacmdadd $xpa grid \
 	{} \
 	XPASendGrid {} {} \
@@ -380,6 +385,11 @@ proc CreateXPA {} {
 	XPASendNan {} {} \
 	XPARcvdNan {} {}
 
+    xpacmdadd $xpa notes \
+	{} \
+	XPASendNotes {} {} \
+	XPARcvdNotes {} {}
+
     xpacmdadd $xpa nrrd \
 	{} \
 	XPASendNRRD {} {} \
@@ -457,8 +467,8 @@ proc CreateXPA {} {
 
     xpacmdadd $xpa psprint \
 	{} \
-	XPASendPSPrint {} {} \
-	XPARcvdPSPrint {} "fillbuf=false"
+	XPASendPrint {} {} \
+	XPARcvdPrint {} "fillbuf=false"
 
     xpacmdadd $xpa quit \
 	{} \
@@ -510,6 +520,11 @@ proc CreateXPA {} {
 	XPASendRotate {} {} \
 	XPARcvdRotate {} "fillbuf=false"
 
+    xpacmdadd $xpa samp \
+	{} \
+	XPASendSAMP {} {} \
+	XPARcvdSAMP {} "fillbuf=false"
+
     xpacmdadd $xpa save \
 	{} \
 	{} {} {} \
@@ -1110,6 +1125,19 @@ proc XPARcvdGIF {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendGraph {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendGraphCmd xpasetbuf $xpa $param}
+    XPACatchError $xpa
+}
+
+proc XPARcvdGraph {xpa cdata param buf len} {
+    XPADebug "XPARcvdGraph" $param
+    InitError xpa
+    catch {set i 0; ProcessGraphCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPASendGrid {xpa cdata param} {
     InitError xpa
     catch {ProcessSendGridCmd xpasetbuf $xpa $param}
@@ -1414,6 +1442,19 @@ proc XPARcvdNan {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendNotes {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendNotesCmd xpasetbuf $xpa $param}
+    XPACatchError $xpa
+}
+
+proc XPARcvdNotes {xpa cdata param buf len} {
+    XPADebug "XPARcvdNotes" $param
+    InitError xpa
+    catch {set i 0; ProcessNotesCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPASendNRES {xpa cdata param} {
     InitError xpa
     catch {ProcessSendNRESCmd xpasetbuf $xpa $param}
@@ -1635,7 +1676,7 @@ proc XPARcvdPrism {xpa cdata param buf len} {
 
 proc XPASendPSPrint {xpa cdata param} {
     InitError xpa
-    catch {ProcessSendPSPrintCmd xpasetbuf $xpa $param}
+    catch {ProcessSendPrintCmd xpasetbuf $xpa $param}
     XPACatchError $xpa
 }
 
@@ -1645,7 +1686,7 @@ proc XPARcvdPSPrint {xpa cdata param buf len} {
     catch {
 	if {[XPAIsLocal]} {
 	    set i 0
-	    ProcessPSPrintCmd param i
+	    ProcessPrintCmd param i
 	} else {
 	    Error [msgcat::mc {This function is not available.}]    
 	}
@@ -1745,6 +1786,19 @@ proc XPARcvdRotate {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendSAMP {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendSAMPCmd xpasetbuf $xpa $param}
+    XPACatchError $xpa
+}
+
+proc XPARcvdSAMP {xpa cdata param buf len} {
+    XPADebug "XPARcvdSAMP" $param
+    InitError xpa
+    catch {set i 0; ProcessSAMPCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPARcvdSave {xpa cdata param buf len} {
     XPADebug "XPARcvdSave" $param
     InitError xpa
@@ -2259,11 +2313,5 @@ proc ProcessXPACmd {varname iname} {
 }
 
 proc ProcessSendXPACmd {proc id param {sock {}} {fn {}}} {
-    global parse
-    set parse(proc) $proc
-    set parse(id) $id
-
-    xpasend::YY_FLUSH_BUFFER
-    xpasend::yy_scan_string $param
-    xpasend::yyparse
+    $proc $id "[XPAInfoResult]\n"
 }
