@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -6,7 +6,6 @@
 #define __colorbarbase_h__
 
 #include "widget.h"
-#include "util.h"
 
 // Widget ConfigSpecs Defines
 
@@ -157,11 +156,13 @@ class ColorbarBase : public Widget {
   virtual void getColormapCmd() =0;
   virtual void getColormapNameCmd(int) =0;
   virtual void getColormapFileNameCmd(int) =0;
+  virtual void getColormapFileNameCmd(const char*) =0;
   virtual void getContrastCmd() =0;
   virtual void getCurrentFileNameCmd() =0;
   virtual void getCurrentIDCmd() =0;
   virtual void getCurrentNameCmd() =0;
   void getInvertCmd();
+  virtual void getTypeCmd() =0;
   void getNumericsCmd();
   virtual void getRGBChannelCmd() =0;
   void getValueCmd(int,int);
@@ -180,6 +181,8 @@ class ColorbarBase : public Widget {
 
   virtual void saveCmd(const char*) {}
   virtual void saveCmd(int, const char*) {}
+  virtual void saveCmd(const char*, const char*) {}
+  virtual void saveVarCmd(const char*, const char*) {}
   virtual void setColorbarCmd(int, float, float, int) {}
   virtual void setColorbarCmd(float, float, float, float, float, float, int) {}
   void setColormapLevelCmd();
