@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -508,13 +508,6 @@ public:
 
   Vector zoom() {return zoom_;}
 
-#ifdef MAC_OSX_TK
-  void macosx();
-  void macosxCrosshair();
-  virtual void macosxGraphics() {}
-  void macosxImage(float, int, int, const Vector&, const Vector&);
-  void macosxMarkers(List<Marker>* ml);
-#endif
 #ifdef __WIN32
   void win32();
   void win32Crosshair();
@@ -994,8 +987,14 @@ public:
   // Graph Commands
   void getHorzCutCmd(char*, char*, const Vector&, Coord::InternalSystem, 
 		     int, Base::CutMethod);
+  void getHorzCutCmd(char*, char*, const Vector&,
+		     Coord::CoordSystem, Coord::SkyFrame,
+		     int, Base::CutMethod);
   void getVertCutCmd(char*, char*, const Vector&, Coord::InternalSystem, 
 		     int, Base::CutMethod);
+  void getVertCutCmd(char*, char*, const Vector&,
+		     Coord::CoordSystem, Coord::SkyFrame,
+		     int, Base::CutMethod);
 
   // Grid Commands
   virtual void gridCmd(Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, 
@@ -1631,9 +1630,6 @@ public:
   void precCmd(int, int, int, int, int, int);
 
   // Print Commands
-#ifdef MAC_OSX_TK
-  void macosxPrintCmd();
-#endif
 #ifdef __WIN32
   void win32PrintCmd();
 #endif
