@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -15,10 +15,6 @@ class Box : public BaseBox {
   void renderXDraw(Drawable, GC, XPoint*, RenderMode);
   void renderPSDraw(int);
 
-#ifdef MAC_OSX_TK
-  void renderMACOSXDraw(Vector*);
-#endif
-
 #ifdef __WIN32
   void renderWIN32Draw(Vector*);
 #endif
