@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -17,10 +17,6 @@ class Circle : public BaseEllipse {
 
   void renderPSDraw();
 
-#ifdef MAC_OSX_TK
-  void renderMACOSXDraw();
-#endif
-
 #ifdef __WIN32
   void renderWIN32Draw();
 #endif
