@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -32,12 +32,6 @@ private:
   void renderPSInclude(PSColorSpace) {}
   void renderPSGC(PSColorSpace);
 
-#ifdef MAC_OSX_TK
-  void renderMACOSX();
-  void renderMACOSXInclude() {}
-  void renderMACOSXGC();
-#endif
-
 #ifdef __WIN32
   void renderWIN32();
   void renderWIN32Include() {}
