@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -24,9 +24,6 @@ class Grid3d : public Grid, public Grid3dBase {
 
   void x11() {doit(X11);}
   void ps(PSColorSpace mode) {mode_=mode; doit(PS);}
-#ifdef MAC_OSX_TK
-  void macosx() {doit(MACOSX);}
-#endif
 #ifdef __WIN32
   void win32() {doit(GWIN32);}
 #endif
