@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -17,9 +17,6 @@ class Polygon : public BasePolygon {
   int isInRef(const Vector& v);
   void renderX(Drawable, Coord::InternalSystem, RenderMode);
   void renderPS(PSColorSpace);
-#ifdef MAC_OSX_TK
-  void renderMACOSX();
-#endif
 #ifdef __WIN32
   void renderWIN32();
 #endif
