@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -20,12 +20,6 @@ class Text : public Marker {
   void renderPSText(PSColorSpace) {}
   void renderPSInclude(PSColorSpace) {}
 
-#ifdef MAC_OSX_TK
-  void renderMACOSX();
-  void renderMACOSXText() {}
-  void renderMACOSXInclude() {}
-#endif
-
 #ifdef __WIN32
   void renderWIN32();
   void renderWIN32Text() {}
